/*********************************************************************
	Component	: oxf
	Model Element	: RiJEvent
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf;

import java.util.*;
//## dependency RiJStateReactive 
import com.ibm.rational.rhapsody.oxf.states.RiJStateReactive;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/RiJEvent.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf 


/**
Base class for all events defined in Rhapsody. Corresponds to OMEvent in the original C++ framework.
*/
//## class RiJEvent 
public class RiJEvent {
    
    /**
    The value marking the event as "ANY_EVENT"
    */
    final public static short ANY_EVENT_ID = -3;		//## attribute ANY_EVENT_ID 
    
    /**
    The value of the ID marking the event as caceled.
    */
    final public static short CANCELLED_EVENT_ID = -4;		//## attribute CANCELLED_EVENT_ID 
    
    final public static short NULL_EVENT_ID = -1;		//## attribute NULL_EVENT_ID 
    
    /**
    The value marking the event as a start behavior event.
    */
    final public static short START_BEHAVIOR_EVENT_ID = -5;		//## attribute START_BEHAVIOR_EVENT_ID 
    
    final public static short TIMEOUT_EVENT_ID = -2;		//## attribute TIMEOUT_EVENT_ID 
    
    private boolean isTriggeredOperation = false;		//## attribute isTriggeredOperation 
    
    /**
    The id of the event
    */
    protected long lId;		//## attribute lId 
    
    /**
    To identify the port that relayed the event
    */
    protected Object port = null;		//## attribute port 
    
    /**
    The destination of the event.
    */
    protected RiJEventConsumer destination;
    
    // Constructors
    
    /**
    Creates a new RiJEventInstance targeted to be consumed by the destination, having an ID equal to eventId.
    */
    // Argument long eventId : 
    /**
    The event's id. Should be a positive number for ordinary events.
    */
    // Argument RiJEventConsumer destination : 
    /**
    The object that will resopnd to this event.
    */
    //## operation RiJEvent(long,RiJEventConsumer) 
    public  RiJEvent(long eventId, RiJEventConsumer destination) {
        initRelations();
        //#[ operation RiJEvent(long,RiJEventConsumer) 
        this.destination = destination;
        this.lId = eventId;
        
        
        //#]
    }
    //## operation RiJEvent() 
    public  RiJEvent() {
        this(0, null);;
        initRelations();
        //#[ operation RiJEvent() 
        
        
        
        //#]
    }
    
    /**
    Marks the event as canceled. The destinantion is  responsible to disregard the event if marked as canceled. 
    */
    //## operation cancel() 
    public void cancel() {
        //#[ operation cancel() 
        lId = CANCELLED_EVENT_ID;
        //#]
    }
    
    /**
    get the RiJEventConsumer instance which is to consume the  event.
    */
    //## operation getDestination() 
    public RiJEventConsumer getDestination() {
        //#[ operation getDestination() 
        return destination;
        
        
        //#]
    }
    
    /**
    get the ID of the event.
    */
    //## operation getID() 
    public long getID() {
        //#[ operation getID() 
        return lId;
        
        
        //#]
    }
    
    //## operation getPort() 
    public Object getPort() {
        //#[ operation getPort() 
         return port;
        //#]
    }
    
    //## operation getTimeoutId() 
    public long getTimeoutId() {
        //#[ operation getTimeoutId() 
        long id = 0;
        if (this instanceof com.ibm.rational.rhapsody.oxf.timeouts.RiJTimeout)
        {
        	id =  ((com.ibm.rational.rhapsody.oxf.timeouts.RiJTimeout)(this)).getTimeoutId();
        }
        return id;
        
        //#]
    }
    
    /**
    Initialize relations (used internaly).
    */
    //## operation initRelations() 
    protected void initRelations() {
        //#[ operation initRelations() 
        //#]
    }
    
    //## operation isEventCancelled() 
    public boolean isEventCancelled() {
        //#[ operation isEventCancelled() 
        if(lId == CANCELLED_EVENT_ID)
            return true;
        else
            return false;
        
        
        //#]
    }
    
    /**
    check if the event is from a given type (has a given id)
    this method should be overriden by client events:
      boolean isTypeOf(long id) { 
    	if (id == <event>_id) return true;
    	return super.isTypeOf(id);
      }
    */
    // Argument long id : 
    /**
    the id (type) to check against
    */
    //## operation isTypeOf(long) 
    public boolean isTypeOf(long id) {
        //#[ operation isTypeOf(long) 
        return getID() == id;
        //#]
    }
    
    /**
    Sets the destination of the event.
    */
    //## operation setDestination(RiJEventConsumer) 
    public void setDestination(RiJEventConsumer p_RiJEventConsumer) {
        //#[ operation setDestination(RiJEventConsumer) 
        destination = p_RiJEventConsumer;
        
        
        //#]
    }
    
    //## operation setPort(Object) 
    public void setPort(Object thePort) {
        //#[ operation setPort(Object) 
        port = thePort;
        //#]
    }
    
    /**
    A convenience method used to send the event to it's destination.
    */
    //## operation toDestination() 
    synchronized public void toDestination() {
        //#[ operation toDestination() 
        if ((destination != null) && (lId != (long)RiJEvent.CANCELLED_EVENT_ID)) {
        	boolean isTerminated = false;
          if (destination instanceof RiJStateReactive) {
            isTerminated = ((RiJStateReactive)destination).isTerminated();
          }
          if (!isTerminated) {
           if (destination.takeEvent(this) == RiJStateReactive.TAKE_EVENT_REACHED_TERMINATOR) {
        		destination = null;
           }
          }
        }
        //#]
    }
    
    //## operation toString() 
    public String toString() {
        //#[ operation toString() 
        String s = "";
        if (lId == TIMEOUT_EVENT_ID)
          s = "Timeout";  
        else if (lId == START_BEHAVIOR_EVENT_ID)
          s = "Start Behavior Event";
        else if (lId == NULL_EVENT_ID) 
          s = "NULL Event";
        else
          s = super.toString();
        return s;
        //#]
    }
    
    public boolean getIsTriggeredOperation() {
        return isTriggeredOperation;
    }
    
    public void setIsTriggeredOperation(boolean p_isTriggeredOperation) {
        isTriggeredOperation = p_isTriggeredOperation;
    }
    
}

