/*********************************************************************
	Component	: oxf
	Model Element	: RiJEventDispatcher
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf;

import java.util.*;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/RiJEventDispatcher.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf 


/**
This class is for handling all event dispatching issues. Currently is is used only by RiJThread.
*/
//## class RiJEventDispatcher 
public class RiJEventDispatcher {
    
    protected RiJEventQueue eventQueue;
    
    // Constructors
    
    public  RiJEventDispatcher() {
        initRelations();
    }
    
    /**
    Cancels the event. Method exists for compatibility with the C++ framework. The event get canceled weather it is in the queue or not.
    */
    // Argument RiJEvent i_event : 
    /**
    The event to be cancled.
    */
    //## operation cancelEvent(RiJEvent) 
    public void cancelEvent(RiJEvent i_event) {
        //#[ operation cancelEvent(RiJEvent) 
        i_event.cancel();
        //#]
    }
    
    /**
    Cancel all events to specified destination.
    */
    // Argument RiJEventConsumer i_destination : 
    /**
    The destionition we need to clear events to.
    */
    //## operation cancelEvents(RiJEventConsumer) 
    public void cancelEvents(RiJEventConsumer i_destination) {
        //#[ operation cancelEvents(RiJEventConsumer) 
        LinkedList eventList = eventQueue.getEventList();
        ListIterator iter=eventList.listIterator(0);
        while (iter.hasNext())
        {
          RiJEvent evt = (RiJEvent)iter.next();
          if (i_destination == evt.getDestination()) 
             evt.cancel();
        }
        
        //#]
    }
    
    /**
    Send all events to their destinations.
    */
    //## operation dispatchAllEvents() 
    public void dispatchAllEvents() {
        //#[ operation dispatchAllEvents() 
        while (eventQueue.isEmpty() == false) {
          eventQueue.get().toDestination();
        }
        //#]
    }
    
    /**
    Send the next event in queue to it's destination.
    */
    //## operation dispatchNextEvent() 
    public void dispatchNextEvent() {
        //#[ operation dispatchNextEvent() 
        RiJEvent event = null;
        if (eventQueue.isEmpty() == false) {
          synchronized(eventQueue) {  
            event = eventQueue.get();
          }
          if (event != null) 
            event.toDestination();
        }
        //#]
    }
    
    //## operation getEventQueue() 
    public RiJEventQueue getEventQueue() {
        //#[ operation getEventQueue() 
        return eventQueue;
        //#]
    }
    
    //## operation newEventQueue() 
    public RiJEventQueue newEventQueue() {
        //#[ operation newEventQueue() 
        eventQueue = new RiJEventQueue();
        return eventQueue;
        
        //#]
    }
    
    /**
    Inserts an event to the queue.
    */
    // Argument RiJEvent i_event : 
    /**
    The event to be queued
    */
    //## operation queueEvent(RiJEvent) 
    public void queueEvent(RiJEvent i_event) {
        //#[ operation queueEvent(RiJEvent) 
        eventQueue.put(i_event);
        
        //#]
    }
    
    protected void initRelations() {
        eventQueue = newEventQueue();
    }
    
}

