/*********************************************************************
	Component	: oxf
	Model Element	: RiJEventQueue
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf;

import java.util.*;
//## dependency AnimServices 
import com.ibm.rational.rhapsody.oxfinst.AnimServices;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/RiJEventQueue.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf 


/**
Used by RiJEventDispacther for dispatching events.
This is NOT intended for external use: instead one may use the supplied RiJMessageQueue.
*/
//## class RiJEventQueue 
public class RiJEventQueue {
    
    protected LinkedList eventList;
    
    // Constructors
    
    public  RiJEventQueue() {
        {
            eventList = new LinkedList();
        }
    }
    
    /**
    Clears all events.
    */
    //## operation clearEventList() 
    synchronized public void clearEventList() {
        //#[ operation clearEventList() 
        eventList.clear();
        
        //#]
    }
    
    /**
    Gets the event and removes it from queue.
    */
    //## operation get() 
    public RiJEvent get() {
        //#[ operation get() 
        ListIterator iter = eventList.listIterator(0);
        RiJEvent event = (RiJEvent)iter.next();
        remove(event);
        
        // may need to notify that an event has been taken,
        // and strip animation information
        RiJEvent ev = AnimServices.initAnimEventTaken(event);
        
        return ev;
        
        //#]
    }
    
    /**
    Returns a clone of the event list.
    */
    //## operation getEventList() 
    public LinkedList getEventList() {
        //#[ operation getEventList() 
        return (LinkedList)(eventList.clone());
        //#]
    }
    
    /**
    true if empty...
    */
    //## operation isEmpty() 
    public boolean isEmpty() {
        //#[ operation isEmpty() 
        if (eventList.size() > 0) return false;
        return true;
        //#]
    }
    
    /**
    Adds an event to queue.
    */
    //## operation put(RiJEvent) 
    public void put(RiJEvent p_RiJEvent) {
        //#[ operation put(RiJEvent) 
        synchronized(eventList) {
            eventList.add(p_RiJEvent);
        }
        // may need to notify that an event is being sent
        AnimServices.initAnimEventSent(p_RiJEvent);
        
        //#]
    }
    
    /**
    Removes an event from queue.
    */
    //## operation remove(RiJEvent) 
    public void remove(RiJEvent p_RiJEvent) {
        //#[ operation remove(RiJEvent) 
        eventList.remove(p_RiJEvent);
        
        //#]
    }
    
}

