/*********************************************************************
	Component	: oxf
	Model Element	: RiJMainThread
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf;

import java.util.*;
//## dependency AnimServices 
import com.ibm.rational.rhapsody.oxfinst.AnimServices;
//## dependency RiJTimeoutManager 
import com.ibm.rational.rhapsody.oxf.timeouts.RiJTimeoutManager;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/RiJMainThread.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf 


/**
This is a singleton class, for the main execution thread.
*/
//## class RiJMainThread 
public class RiJMainThread extends RiJThread {
    
    protected static boolean defaultThreadInitialized = false;		//## attribute defaultThreadInitialized 
    
    private static RiJMainThread theMainThreadObject;		//## attribute theMainThreadObject 
    
    
    // Constructors
    
    //## operation RiJMainThread() 
    private  RiJMainThread() {
        super("RiJMainThread");
        //#[ operation RiJMainThread() 
        //#]
    }
    
    /**
    Initialization of essential threads.
    */
    //## operation OXFInit() 
    public static final void OXFInit() {
        //#[ operation OXFInit() 
        RiJOXF.Init();
        
        //#]
    }
    
    /**
    Initialization of essential threads.
    */
    //## operation OXFInit(String,long,long) 
    public static final void OXFInit(String hostName, long i_timeTick, long i_maxTime) {
        //#[ operation OXFInit(String,long,long) 
        RiJOXF.Init(hostName, i_timeTick, i_maxTime);
        
        //#]
    }
    
    /**
    Initialization of essential threads.
    hostName is now ignored.
    */
    //## operation OXFInit(String,long) 
    public static final void OXFInit(String hostName, long i_timeTick) {
        //#[ operation OXFInit(String,long) 
        RiJOXF.Init(hostName, i_timeTick);
        
        //#]
    }
    
    /**
    Initialization of essential threads.
    */
    // Argument int portNumber : 
    /**
    A TCP/IP port number.
    */
    //## operation OXFInit(String,long,long,boolean,int) 
    public static final void OXFInit(String hostName, long i_timeTick, long i_maxTime, boolean realTime, int portNumber) {
        //#[ operation OXFInit(String,long,long,boolean,int) 
        RiJOXF.Init(hostName, i_timeTick, i_maxTime, realTime, portNumber, false);
        //#]
    }
    
    /**
    Initialization of essential threads.
    */
    // Argument String hostname : 
    /**
    The hostname running the animation browser.
    */
    //## operation OXFInit(String) 
    public static final void OXFInit(String hostname) {
        //#[ operation OXFInit(String) 
        RiJOXF.Init(hostname);
        
        //#]
    }
    
    /**
    Initialization of essential threads.
    */
    //## operation OXFInit(String,long,long,boolean) 
    public static final void OXFInit(String hostName, long i_timeTick, long i_maxTime, boolean realTime) {
        //#[ operation OXFInit(String,long,long,boolean) 
        RiJOXF.Init(hostName, i_timeTick, i_maxTime, realTime, 0, false);
        //#]
    }
    
    /**
    starts the main thread.
    */
    //## operation OXFStart(boolean) 
    public static final void OXFStart(boolean doFork) {
        //#[ operation OXFStart(boolean) 
        RiJOXF.Start(doFork);
        //#]
    }
    
    /**
    starts the main thread.
    */
    //## operation OXFStart() 
    public static final void OXFStart() {
        //#[ operation OXFStart() 
        RiJOXF.Start();
        //#]
    }
    
    //## operation initializeDefaultThread(RiJThread) 
    public static void initializeDefaultThread(RiJThread theThread) {
        //#[ operation initializeDefaultThread(RiJThread) 
        if ((theThread != null) && (defaultThreadInitialized == false)) {
            defaultThreadInitialized = true;
            // prevent calling createNewThread if doFork will be false
            theThread.setThread(Thread.currentThread());   
            // At this stage SYSTEM is not idle.
            RiJTimeoutManager.instance().incNonIdleCount();
            AnimServices.initAnimThread(theThread);
        }    
        //#]
    }
    
    /**
    get the MainThread object (create if necessary)
    */
    //## operation instance() 
    public static RiJThread instance() {
        //#[ operation instance() 
        // check for a user default active class
        RiJThread theInstance = RiJOXF.getTheDefaultActiveClass();
        if ((theInstance == null) && (theMainThreadObject == null)) {
            // no user active class create the RiJMainThread instance, 
            // and register it as the active class
            theMainThreadObject = new RiJMainThread();
            RiJOXF.setTheDefaultActiveClass(theMainThreadObject);
            theInstance = theMainThreadObject;
        }
        initializeDefaultThread(theInstance);
        return theInstance;
        //#]
    }
    
    /**
    The main thread may do it's infinte loop without creating a new separate thread. That's why if doFork is false no new thread is created.
    */
    //## operation start(boolean) 
    public void start(boolean doFork) {
        //#[ operation start(boolean) 
        if (doFork) {
        	thread = null;
          	
          	//create a new thread and switch the current stepper thread to the new one
          	//(this is done to avoid creating another stepper)
        	if (name == null)
        		thread = new Thread(this);
        	else 
        		thread = new Thread(this, name);
            thread.setPriority(priority);
        			
        	AnimServices.switchJavaThread(Thread.currentThread(), thread);
        			
        	thread.start();
        }
        else 
        {
          
            wasStarted = true;          
            boolean terminate = false;
            Thread thisThread = Thread.currentThread();
            
            
            
            while (!terminate) {  
        
                
             // if suspended wait to be resumed
             synchronized(this) 
             {
                while (threadSuspend) 
                {
                   try 
                   {
                     wait();                
                   }
                   catch (InterruptedException e) {
                   }
                }
             }
             
             RiJTimeoutManager.instance().decNonIdleCount();
            
             // wait for an event
             synchronized(eventQueue)
             {   
                 while (eventQueue.isEmpty()) {
                    AnimServices.notifyIdle(this);
                    try {      
                                      
                     eventQueue.wait();
        
                    }                     
                    catch (InterruptedException e) {
                    }
                 }
             }
        
             RiJTimeoutManager.instance().incNonIdleCount();
             
             // do the job
             execute();
            }
        }
        //#]
    }
    
    private static boolean getDefaultThreadInitialized() {
        return defaultThreadInitialized;
    }
    
    private static void setDefaultThreadInitialized(boolean p_defaultThreadInitialized) {
        defaultThreadInitialized = p_defaultThreadInitialized;
    }
    
}

