/*********************************************************************
	Component	: oxf
	Model Element	: RiJOXF
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf;

import java.util.*;
//## dependency AnimServices 
import com.ibm.rational.rhapsody.oxfinst.AnimServices;
//## dependency RiJTimer 
import com.ibm.rational.rhapsody.oxf.services.RiJTimer;
//## dependency RiJTimerFactory 
import com.ibm.rational.rhapsody.oxf.services.RiJTimerFactory;
//## dependency RiJTimeoutManager 
import com.ibm.rational.rhapsody.oxf.timeouts.RiJTimeoutManager;
//## dependency RiJOXFTimerFactory 
import com.ibm.rational.rhapsody.oxf.services.RiJOXFTimerFactory;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/RiJOXF.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf 


/**
The Object eXecution Framework main services class
*/
//## class RiJOXF 
public class RiJOXF {
    
    /**
    User alternative active class (instead of RiJMainThread)
    */
    private static RiJThread theDefaultActiveClass = null;		//## attribute theDefaultActiveClass 
    
    private static RiJTimerFactory theTimerFactory = null;		//## attribute theTimerFactory 
    
    
    /**
    Initialization of essential threads.
    */
    //## operation Init() 
    public static final void Init() {
        //#[ operation Init() 
        Init(null, RiJTimeoutManager.DEF_TIME_TICK);
        
        //#]
    }
    
    /**
    Initialization of essential threads.
    */
    // Argument String hostname : 
    /**
    The hostname running the animation browser.
    */
    //## operation Init(String) 
    public static final void Init(String hostname) {
        //#[ operation Init(String) 
        Init(hostname, RiJTimeoutManager.DEF_TIME_TICK);
        
        //#]
    }
    
    /**
    Initialization of essential threads.
    hostName is now ignored.
    */
    //## operation Init(String,long) 
    public static final void Init(String hostName, long i_timeTick) {
        //#[ operation Init(String,long) 
        Init(hostName, i_timeTick, RiJTimeoutManager.DEF_MAX_TIME);
        
        //#]
    }
    
    /**
    Initialization of essential threads.
    */
    //## operation Init(String,long,long) 
    public static final void Init(String hostName, long i_timeTick, long i_maxTime) {
        //#[ operation Init(String,long,long) 
        Init(hostName, i_timeTick, i_maxTime, true);
        
        //#]
    }
    
    /**
    Initialization of essential threads.
    */
    // Argument int portNumber : 
    /**
    A TCP/IP port number.
    */
    //## operation Init(String,long,long,boolean,int,boolean) 
    public static final void Init(String hostName, long i_timeTick, long i_maxTime, boolean realTime, int portNumber, boolean suspendResumeByDebugger) {
        //#[ operation Init(String,long,long,boolean,int,boolean) 
        // better go on with simulated time instead of real time.
        boolean simulatedTime = !realTime; 
        
        //if the tick time or the max time are set to 0, set them with default values
        if(i_timeTick == 0)
            i_timeTick = RiJTimeoutManager.DEF_TIME_TICK;
        
        if(i_maxTime == 0)
            i_maxTime = RiJTimeoutManager.DEF_MAX_TIME;
        
        // set the default timer factory
        setTheTimerFactory( (RiJTimerFactory) new RiJOXFTimerFactory() );
        
        // initialize the default active class 
        RiJTimeoutManager.instance(i_timeTick, i_maxTime, simulatedTime);
        
        // initializ animation
        AnimServices.initAnimSession(hostName, portNumber, suspendResumeByDebugger);
        
        //#]
    }
    
    /**
    Initialization of essential threads.
    */
    //## operation Init(String,long,long,boolean) 
    public static final void Init(String hostName, long i_timeTick, long i_maxTime, boolean realTime) {
        //#[ operation Init(String,long,long,boolean) 
        // Eldad Temp.: 0 currently indicates an unknown port.
        // I don't want to create a direct 
        // dependency between oxf and animation.
        Init(hostName, i_timeTick, i_maxTime, realTime, null);
        //#]
    }
    
    /**
    Initialization of essential threads.
    */
    //## operation Init(String,long,long,boolean,String[]) 
    public static final void Init(String hostName, long i_timeTick, long i_maxTime, boolean realTime, String[] args) {
        //#[ operation Init(String,long,long,boolean,String[]) 
        boolean byDebugger = shouldSuspendResumeByDebugger(args); 
        Init(hostName, i_timeTick, i_maxTime, realTime, 0, byDebugger);
        
        
        //#]
    }
    
    /**
    starts the main thread.
    */
    //## operation Start() 
    public static final void Start() {
        //#[ operation Start() 
        Start(false);
        //#]
    }
    
    /**
    starts the main thread.
    */
    //## operation Start(boolean) 
    public static final void Start(boolean doFork) {
        //#[ operation Start(boolean) 
        RiJMainThread.instance().start(doFork);
        //#]
    }
    
    /**
    get the default active class
    */
    //## operation getTheDefaultActiveClass() 
    public static RiJThread getTheDefaultActiveClass() {
        //#[ operation getTheDefaultActiveClass() 
        return theDefaultActiveClass;
        
        //#]
    }
    
    //## operation getTheTimerFactory() const 
    public static RiJTimerFactory getTheTimerFactory() {
        //#[ operation getTheTimerFactory() const 
        return theTimerFactory;
        
        //#]
    }
    
    /**
    set the default active class.
    the setting must be made before the call to RiJOXF.Init()
    return true on success
    */
    //## operation setTheDefaultActiveClass(RiJThread) 
    public static boolean setTheDefaultActiveClass(RiJThread userDefaultActiveClass) {
        //#[ operation setTheDefaultActiveClass(RiJThread) 
        boolean result = false;
        if (theDefaultActiveClass == null) {
            theDefaultActiveClass = userDefaultActiveClass;
            result = true;
        }
        return result;
        
        //#]
    }
    
    /**
    set the timer factory
    the setting must be made before the call to RiJOXF.Init()
    return true on success
    */
    //## operation setTheTimerFactory(RiJTimerFactory) 
    public static boolean setTheTimerFactory(RiJTimerFactory userTimerFactory) {
        //#[ operation setTheTimerFactory(RiJTimerFactory) 
        boolean result = false;
        if (theTimerFactory == null) {
            theTimerFactory = userTimerFactory;
            result = true;
        }
        return result;
        
        //#]
    }
    
    //## operation shouldSuspendResumeByDebugger(String[]) 
    public static final boolean shouldSuspendResumeByDebugger(String[] args) {
        //#[ operation shouldSuspendResumeByDebugger(String[]) 
        int found = -1;
        if (args != null) {
        	String[] newArgs = new String[args.length];
         	System.arraycopy(args, 0, newArgs, 0, args.length);
          	Arrays.sort(newArgs);
           	found = Arrays.binarySearch(newArgs, new String("-suspendResumeAnimationByDebugger"));
        }
        return (found >= 0);
        //#]
    }
    
}

