/*********************************************************************
	Component	: oxf
	Model Element	: RiJReactive
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf;

import java.util.*;
//## dependency AnimServices 
import com.ibm.rational.rhapsody.oxfinst.AnimServices;
//## dependency RiJTimedEvent 
import com.ibm.rational.rhapsody.oxf.timeouts.RiJTimedEvent;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/RiJReactive.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf 


/**
RiJReactive is able to receive events but also queue events into the Thread that dispatches events to it's instance.
*/
//## class RiJReactive 
abstract public class RiJReactive implements RiJEventConsumer {
    
    protected RiJThread itsRiJThread;
    
    // Constructors
    
    //## operation RiJReactive(RiJThread) 
    public  RiJReactive(RiJThread thread) {
        //#[ operation RiJReactive(RiJThread) 
        itsRiJThread = thread;
        
        //#]
    }
    //## operation RiJReactive() 
    public  RiJReactive() {
        //#[ operation RiJReactive() 
        //#]
    }
    
    /**
    create new event and queue it
    */
    //## operation _gen(long) 
    public void _gen(long eventID) {
        //#[ operation _gen(long) 
        // create the event using the id
        RiJEvent event = new RiJEvent(eventID, this);
        
        // send it
        _gen(event);
        
        //#]
    }
    
    /**
    Set the event's destination to this and queue it.
    */
    //## operation _gen(RiJEvent) 
    public void _gen(RiJEvent event) {
        //#[ operation _gen(RiJEvent) 
        event.setDestination(this);
        queueEvent(event);
        
        //#]
    }
    
    //## operation genTimedEvent(long,long) 
    public void genTimedEvent(long eventID, long timeInterval) {
        //#[ operation genTimedEvent(long,long) 
        RiJTimedEvent timedEvent = 
        new RiJTimedEvent(eventID, this, timeInterval, itsRiJThread);
        //#]
    }
    
    //## operation getItsRiJThread() const 
    public RiJThread getItsRiJThread() {
        //#[ operation getItsRiJThread() const 
        return itsRiJThread;
        
        //#]
    }
    
    //## operation getThread() 
    public RiJThread getThread() {
        //#[ operation getThread() 
        return itsRiJThread;
        
        //#]
    }
    
    /**
    queues an event into the associated event dispatcher. 
    */
    //## operation queueEvent(RiJEvent) 
    public void queueEvent(RiJEvent event) {
        //#[ operation queueEvent(RiJEvent) 
        // may need to add animation information
        RiJEvent ev = AnimServices.initAnimEvent(event, itsRiJThread.getJThread());
        
        itsRiJThread.queueEvent(ev);
        
        //#]
    }
    
    //## operation setItsRiJThread(RiJThread) 
    public void setItsRiJThread(RiJThread p_RiJThread) {
        //#[ operation setItsRiJThread(RiJThread) 
        itsRiJThread = p_RiJThread;
        
        //#]
    }
    
    //## operation setThread(RiJThread) 
    public void setThread(RiJThread p_RiJThread) {
        //#[ operation setThread(RiJThread) 
        itsRiJThread = p_RiJThread;
        
        //#]
    }
    
    //## operation takeTrigger() 
    public void takeTrigger() {
        //#[ operation takeTrigger() 
        //#]
    }
    
}

