/*********************************************************************
	Component	: oxf
	Model Element	: RiJMessageQueue
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf.services;

import java.util.*;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/services/RiJMessageQueue.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf::services 


/**
Serves as message queue. Has the ability to make consumers threads pend for messages. 
*/
//## class RiJMessageQueue 
public class RiJMessageQueue {
    
    protected LinkedList msgList;		//## attribute msgList 
    
    
    // Constructors
    
    //## operation RiJMessageQueue() 
    public  RiJMessageQueue() {
        //#[ operation RiJMessageQueue() 
        msgList = new LinkedList();
        //#]
    }
    
    /**
    clear all messages from queue
    */
    //## operation clear() 
    synchronized public void clear() {
        //#[ operation clear() 
        msgList.clear();
        //#]
    }
    
    /**
    Get next message and remove from queue.
    */
    //## operation get() 
    synchronized public Object get() {
        //#[ operation get() 
        ListIterator iter=msgList.listIterator(0);
        Object o = iter.next();
        remove(o);
        return o;
        //#]
    }
    
    /**
    Returns a copy of the contained list. The messages are not cloned.
    */
    //## operation getMessageList() 
    public LinkedList getMessageList() {
        //#[ operation getMessageList() 
        return (LinkedList)msgList.clone();
        //#]
    }
    
    //## operation isEmpty() 
    public boolean isEmpty() {
        //#[ operation isEmpty() 
        if (msgList.size() > 0) return false;
        return true;
        //#]
    }
    
    /**
    Makes thread to wait until new messages arrive. If timeout expires an InterruptedException is thrown.
    */
    //## operation pend(long) 
    synchronized public void pend(long timeout) throws InterruptedException {
        //#[ operation pend(long) 
        // makes executing thread wait.
        wait(timeout);
        //#]
    }
    
    /**
    equivalent for pend(0) -- wait indefinitely for new messages.
    */
    //## operation pend() 
    synchronized public void pend() throws InterruptedException {
        //#[ operation pend() 
        pend(0);
        //#]
    }
    
    /**
    adds a message to queue. 
    */
    //## operation put(Object) 
    synchronized public void put(Object msg) {
        //#[ operation put(Object) 
        msgList.add(msg);
        notify(); // wake pending threads
        //#]
    }
    
    /**
    remove object o from message queue. (method equals is used).
    */
    //## operation remove(Object) 
    public void remove(Object o) {
        //#[ operation remove(Object) 
        msgList.remove(o);
        //#]
    }
    
}

