/*********************************************************************
	Component	: oxf
	Model Element	: RiJMutex
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf.services;

import java.util.*;
//## attribute lockerThread 
import java.lang.Thread;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/services/RiJMutex.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf::services 


/**
Mutex implementation in Java.
*/
//## class RiJMutex 
public class RiJMutex {
    
    final public static short ALREADY_UNLOCKED = -2;		//## attribute ALREADY_UNLOCKED 
    
    final public static short NOT_OWNER = -3;		//## attribute NOT_OWNER 
    
    final public static short SUCCESS = 0;		//## attribute SUCCESS 
    
    /**
    The thread that locks the mutex.
    */
    private Thread lockerThread;		//## attribute lockerThread 
    
    
    // Constructors
    
    //## operation RiJMutex() 
    public  RiJMutex() {
        //#[ operation RiJMutex() 
        lockerThread = null;
        //#]
    }
    
    /**
    unlock mutex for others to lock.
    */
    //## operation free() 
    synchronized public short free() {
        //#[ operation free() 
        if (lockerThread == null) 
        	return ALREADY_UNLOCKED;
        if (lockerThread != Thread.currentThread()) 
        	return NOT_OWNER;
        lockerThread = null;
        notify(); // this is the last thing to be done
        return SUCCESS;
        //#]
    }
    
    /**
    try to lock, but give up after timeout. timeout = 0 equivalent to infinity.
    */
    //## operation lock(long) 
    synchronized public void lock(long timeout) throws InterruptedException {
        //#[ operation lock(long) 
        Thread currentThread = Thread.currentThread();
        if (lockerThread == currentThread)
          return;
        
        if (lockerThread == null) { // not locked
          lockerThread = Thread.currentThread();
          return;
        }
        
        // blocking current thread
        wait(timeout);  
        // now lock it yourself
        lockerThread = Thread.currentThread(); // give ownership to the waiter
        
        
        
        
        //#]
    }
    
    /**
    try to lock, wailt infinitly until able.
    */
    //## operation lock() 
    synchronized public void lock() throws InterruptedException {
        //#[ operation lock() 
        lock(0);
        //#]
    }
    
}

