/*********************************************************************
	Component	: oxf
	Model Element	: RiJSimpleTimer
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf.services;

import java.util.*;
//## operation getThread() 
import java.lang.Thread;
//## class RiJSimpleTimer 
import java.lang.Runnable;
//## dependency AnimServices 
import com.ibm.rational.rhapsody.oxfinst.AnimServices;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/services/RiJSimpleTimer.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf::services 


/**
This class notifies a listener class (TimerListener) every timeInterval milliseconds. Every instance runs ir's own thread and notifies a single TimerListener.
*/
//## class RiJSimpleTimer 
public class RiJSimpleTimer implements Runnable, RiJTimer {
    
    /**
    If true, a single notification is made and the thread terminates.
    */
    protected boolean oneShot;		//## attribute oneShot 
    
    protected long refTime = 0;		//## attribute refTime 
    
    /**
    Holds the thread initiated by the timer;
    */
    protected Thread thread;		//## attribute thread 
    
    /**
    The time interval between notifications.
    */
    private long tmInterval;		//## attribute tmInterval 
    
    protected RiJTimerListener timeoutListener;
    
    // Constructors
    
    // Argument RiJTimerListener i_tmListener : 
    /**
    The timerListener which should be notified. If this is null no timer is created.
    */
    // Argument long i_mSecs : 
    /**
    The milli-seconds interval.
    */
    //## operation RiJSimpleTimer(RiJTimerListener,long,boolean) 
    public  RiJSimpleTimer(RiJTimerListener i_tmListener, long i_mSecs, boolean i_oneShot) {
        //#[ operation RiJSimpleTimer(RiJTimerListener,long,boolean) 
        timeoutListener = i_tmListener;
        tmInterval = i_mSecs;
        oneShot = i_oneShot;
        //#]
    }
    //## operation RiJSimpleTimer(RiJTimerListener,long) 
    public  RiJSimpleTimer(RiJTimerListener i_tmListener, long i_tmInterval) {
        //#[ operation RiJSimpleTimer(RiJTimerListener,long) 
        this(i_tmListener, i_tmInterval, false);
        //#]
    }
    public  RiJSimpleTimer() {
    }
    
    //## operation getThread() 
    public Thread getThread() {
        //#[ operation getThread() 
        return thread;
        //#]
    }
    
    /**
    Stops the timer abruptly.
    */
    //## operation interrupt() 
    public void interrupt() {
        //#[ operation interrupt() 
        thread.interrupt();
        //#]
    }
    
    //## operation run() 
    public void run() {
        //#[ operation run() 
        if (oneShot) {
          tm();
        }
        else
        {  
          //initialize the 'refTime' with the current system time,
          //then for each iteration add to it the 'tmInterval'
          refTime = System.currentTimeMillis();
          while(thread == Thread.currentThread()) {  
          	AnimServices.notifyIdle(thread);
            refTime += tmInterval;
            tm();
          }
        }
        
        
        
        //#]
    }
    
    //## operation start() 
    public void start() {
        //#[ operation start() 
        if ((timeoutListener == null) || (tmInterval == 0)) 
          return;
        thread = new Thread(this);
        thread.setName("RiJSimpleTimer");
        thread.start();
        //#]
    }
    
    //## operation stop() 
    public void stop() {
        //#[ operation stop() 
        thread = null;
        //#]
    }
    
    /**
    Sleeps and notifiers the listener.
    */
    //## operation tm() 
    private void tm() {
        //#[ operation tm() 
        try { 
          //the JVM time can sometimes proceed, but this thread time didn't
          //(could happen when another thread get a long CPU time). Therefore,
          //the timer should 'sleep' only the remaining of the 'tmInterval'
          long delayTime = tmInterval;
          if (refTime > 0)
              delayTime = refTime - System.currentTimeMillis();
        
          if (delayTime > 0)
          	  Thread.sleep(delayTime);
          timeoutListener.notifyTime();
        } catch (InterruptedException e) {
          timeoutListener.handleTimerInterrupt(this);
        }
        
        //#]
    }
    
    public RiJTimerListener getTimeoutListener() {
        return timeoutListener;
    }
    
}

