/*********************************************************************
	Component	: oxf
	Model Element	: RiJOrState
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf.states;

import java.util.*;
//## dependency oxf 
import com.ibm.rational.rhapsody.oxf.*;
//## operation takeEvent(RiJEvent) 
import com.ibm.rational.rhapsody.oxf.RiJEvent;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/states/RiJOrState.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf::states 


/**
A state decomposed into exclusive substates which means that the object will be exclusively in one of  its substates.
OR
A state containing one or more substates, where a single substate is active as long as the state (the or-state) is active.
*/
//## class RiJOrState 
public class RiJOrState extends RiJState {
    
    protected RiJState activeSubState;
    
    // Constructors
    
    //## operation RiJOrState(RiJOrState) 
    public  RiJOrState(RiJOrState parent) {
        //#[ operation RiJOrState(RiJOrState) 
        this.parent = parent;
        //#]
    }
    public  RiJOrState() {
    }
    
    //## operation entDef() 
    public void entDef() throws StateEnterException {
        //#[ operation entDef() 
        enter();
        
        //#]
    }
    
    /**
    enter the state
    */
    //## operation enter() 
    public void enter() {
        //#[ operation enter() 
        if (parent != null) 
          ((RiJOrState)parent).setActiveSubState(this);
        //#]
    }
    
    /**
    exits the state
    */
    //## operation exit() 
    public void exit() {
        //#[ operation exit() 
        if (activeSubState != null) {
          activeSubState.exit();
          activeSubState = null;
        }
        //#]
    }
    
    //## operation getActiveSubState() 
    public RiJState getActiveSubState() {
        //#[ operation getActiveSubState() 
        return activeSubState;
        
        //#]
    }
    
    //## operation in() 
    public boolean in() {
        //#[ operation in() 
        if (parent == null) // root state
          return true;
        return (((RiJOrState)parent).getActiveSubState() == this);
        //#]
    }
    
    //## operation takeEvent(RiJEvent) 
    public int takeEvent(RiJEvent event) {
        //#[ operation takeEvent(RiJEvent) 
        if (parent == null) {
          return RiJStateReactive.TAKE_EVENT_NOT_CONSUMED;
        }
        return parent.takeEvent(event);
        
        //#]
    }
    
    public void setActiveSubState(RiJState p_RiJState) {
        activeSubState = p_RiJState;
    }
    
}

