/*********************************************************************
	Component	: oxf
	Model Element	: RiJState
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf.states;

import java.util.*;
//## dependency oxf 
import com.ibm.rational.rhapsody.oxf.*;
//## operation takeEvent(RiJEvent) 
import com.ibm.rational.rhapsody.oxf.RiJEvent;
//## class RiJState 
import com.ibm.rational.rhapsody.oxf.RiJEventConsumer;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/states/RiJState.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf::states 


/**
An  class for a UML state.
UML State: An abstract metaclass that models a situation which some (usually implicit) invariant condition holds. 
This is present for comaptibilty with C++.
*/
//## class RiJState 
abstract public class RiJState implements RiJEventConsumer {
    
    final public static int TAKE_EVENT_UNKNOWN_FAIL = RiJStateReactive.TAKE_EVENT_UNKNOWN_FAIL;		//## attribute TAKE_EVENT_UNKNOWN_FAIL 
    
    protected RiJImplicitState itsImplicitState;
    protected RiJState parent;
    
    // Constructors
    
    // Argument RiJOrState parent : 
    /**
    this.parent = parent;
    */
    //## operation RiJState(RiJOrState) 
    public  RiJState(RiJOrState parent) {
        //#[ operation RiJState(RiJOrState) 
        this.parent = parent;
        
        //#]
    }
    public  RiJState() {
    }
    
    /**
    do a default transition into the state.
    */
    //## operation entDef() 
    public void entDef() throws StateEnterException {
        //#[ operation entDef() 
        enter();
        //#]
    }
    
    /**
    enter the state
    */
    //## operation enter() 
    public void enter() {
        //#[ operation enter() 
        ((RiJOrState)parent).setActiveSubState(this);
        //#]
    }
    
    /**
    exits the state
    */
    //## operation exit() 
    public void exit() {
        //#[ operation exit() 
        //#]
    }
    
    //## operation getParent() 
    public RiJState getParent() {
        //#[ operation getParent() 
        return parent;
        
        //#]
    }
    
    /**
    true if the class is currently in this state.
    */
    //## operation in() const 
    public abstract boolean in();
    
    //## operation takeEvent(RiJEvent) 
    public int takeEvent(RiJEvent event) {
        //#[ operation takeEvent(RiJEvent) 
        if (parent != null) {
          return parent.takeEvent(event);
        }
        return TAKE_EVENT_UNKNOWN_FAIL;
        //#]
    }
    
    public RiJImplicitState getItsImplicitState() {
        return itsImplicitState;
    }
    
    public void __setItsImplicitState(RiJImplicitState p_RiJImplicitState) {
        itsImplicitState = p_RiJImplicitState;
    }
    
    public void _setItsImplicitState(RiJImplicitState p_RiJImplicitState) {
        if(itsImplicitState != null)
            {
                itsImplicitState.__setItsActiveState(null);
            }
        __setItsImplicitState(p_RiJImplicitState);
    }
    
    public void setItsImplicitState(RiJImplicitState p_RiJImplicitState) {
        if(p_RiJImplicitState != null)
            {
                p_RiJImplicitState._setItsActiveState(this);
            }
        _setItsImplicitState(p_RiJImplicitState);
    }
    
    public void _clearItsImplicitState() {
        itsImplicitState = null;
    }
    
    public void setParent(RiJState p_RiJState) {
        parent = p_RiJState;
    }
    
}

