/*********************************************************************
	Component	: oxf
	Model Element	: RiJSimulatedTimer
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf.timeouts;

import java.util.*;
//## dependency AnimServices 
import com.ibm.rational.rhapsody.oxfinst.AnimServices;
//## class RiJSimulatedTimer 
import com.ibm.rational.rhapsody.oxf.services.RiJSimpleTimer;
//## operation RiJSimulatedTimer(RiJTimerListener) 
import com.ibm.rational.rhapsody.oxf.services.RiJTimerListener;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/timeouts/RiJSimulatedTimer.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf::timeouts 


/**
This timer invokes the RiJTimerListener when system is idle. It is executed in a low priotiry and yields before in voking the RiJTimerListener.
This class is used in the framework by the RiJTimoutManager when running in a simulated time model.
*/
//## class RiJSimulatedTimer 
public class RiJSimulatedTimer extends RiJSimpleTimer {
    
    /**
    This is a reference counter used by the active instances to indicate if their event queues are empty or not. 
    In simulated time, time does not advance unless all threads are idle or the user explicitly uses RiJTimeoutManager.consumeTime()
    */
    protected int nonIdleThreadsCounter = 0;		//## attribute nonIdleThreadsCounter 
    
    
    // Constructors
    
    // Argument RiJTimerListener i_tmListener : 
    /**
    The timer listener.
    */
    //## operation RiJSimulatedTimer(RiJTimerListener) 
    public  RiJSimulatedTimer(RiJTimerListener i_tmListener) {
        //#[ operation RiJSimulatedTimer(RiJTimerListener) 
        timeoutListener = i_tmListener;
        //#]
    }
    
    //## operation decNonIdleCount() 
    public void decNonIdleCount() {
        //#[ operation decNonIdleCount() 
        if (nonIdleThreadsCounter > 0)
            --nonIdleThreadsCounter;
        
        //#]
    }
    
    /**
    returns the value of nonIdleThreadsCounter
    */
    //## operation getNonIdleThreadsCounter() 
    public int getNonIdleThreadsCounter() {
        //#[ operation getNonIdleThreadsCounter() 
        return nonIdleThreadsCounter;
        //#]
    }
    
    //## operation incNonIdleCount() 
    public void incNonIdleCount() {
        //#[ operation incNonIdleCount() 
        ++nonIdleThreadsCounter;
        
        //#]
    }
    
    //## operation run() 
    public void run() {
        //#[ operation run() 
        
        while(thread == Thread.currentThread()) { 
        	AnimServices.notifyIdle(thread);
            tm();
        }
        
        
        
        
        //#]
    }
    
    //## operation start() 
    public void start() {
        //#[ operation start() 
        if (timeoutListener == null)
          return;
        thread = new Thread(this);
        thread.start();
        //#]
    }
    
    /**
    Sleeps and notifiers the listener.
    */
    //## operation tm() 
    private void tm() {
        //#[ operation tm() 
        // since the thread is running at MIN_PRIORITY
        // other threads would start running  
        thread.yield();
        if (nonIdleThreadsCounter == 0) {
            timeoutListener.notifyTime();
        }
        
        //#]
    }
    
}

