/*********************************************************************
	Component	: oxf
	Model Element	: RiJTimeout
	Licensed Materials - Property of IBM
	(c) Copyright IBM Corporation 2008. All Rights Reserved.	
*********************************************************************/

package com.ibm.rational.rhapsody.oxf.timeouts;

import java.util.*;
//## attribute creatingThread 
import java.lang.Thread;
//## class RiJTimeout 
import com.ibm.rational.rhapsody.oxf.RiJEvent;
//## dependency RiJEventConsumer 
import com.ibm.rational.rhapsody.oxf.RiJEventConsumer;

//----------------------------------------------------------------------------
// com/ibm/rational/rhapsody/oxf/timeouts/RiJTimeout.java                                                                  
//----------------------------------------------------------------------------

//## package com::ibm::rational::rhapsody::oxf::timeouts 


/**
This is a specialized type of event used to notify the expiarion of a time period. 
*/
//## class RiJTimeout 
public class RiJTimeout extends RiJEvent {
    
    /**
    Remember the thread that is creating this timeout. It is needed during animation.
    */
    public Thread creatingThread;		//## attribute creatingThread 
    
    /**
    The "absolute" time when to fire the timout. The absolute time is relative to the time frame kept by the RiJTimerManager.
    */
    protected long dueTime;		//## attribute dueTime 
    
    /**
    The state where the timeout created. Used for animation\tracing purposes.
    */
    protected String stateName;		//## attribute stateName 
    
    /**
    The time interval in milli seconds between the scheduling and firing the timout.
    */
    protected long timeInterval;		//## attribute timeInterval 
    
    protected long timeoutID;		//## attribute timeoutID 
    
    protected RiJTimeoutManager timeoutManager;
    
    // Constructors
    
    // Argument long tmID : 
    /**
    timeout id.
    */
    // Argument RiJEventConsumer destination : 
    /**
    The destination of the timeout, not it's an event consumer not event handler as in common events. This is due to the fact that the timer manager will use the destination for queuing the timeout, so we need the  destination to be able to queue it's own events.
    */
    // Argument long timeInterval : 
    /**
    The time interval in milli seconds for firing the timout event.
    */
    // Argument String stateName : 
    /**
    The name of the state where the timeout was created.
    */
    //## operation RiJTimeout(long,RiJEventConsumer,long,String) 
    public  RiJTimeout(long tmID, RiJEventConsumer destination, long timeInterval, String stateName) {
        //#[ operation RiJTimeout(long,RiJEventConsumer,long,String) 
        super(TIMEOUT_EVENT_ID, destination);
        this.timeInterval = timeInterval;
        this.timeoutID = tmID;
        this.stateName = stateName;
        this.creatingThread = Thread.currentThread();
        
        //#]
    }
    //## operation RiJTimeout(long,RiJEventConsumer,long) 
    public  RiJTimeout(long tmID, RiJEventConsumer destination, long timeInterval) {
        this(tmID, destination, timeInterval,"No State");
        //#[ operation RiJTimeout(long,RiJEventConsumer,long) 
        //#]
    }
    
    /**
    Compares two timeouts (their id and destinations)
    */
    //## operation equals(Object) 
    public boolean equals(Object tmObj) {
        //#[ operation equals(Object) 
        RiJTimeout tm = (RiJTimeout) tmObj;
        return ((tm.timeoutID == timeoutID) &&
                (tm.destination == destination));
        
        
        //#]
    }
    
    //## operation getDueTime() 
    public long getDueTime() {
        //#[ operation getDueTime() 
        return dueTime;
        //#]
    }
    
    //## operation getTimeInterval() const 
    public long getTimeInterval() {
        //#[ operation getTimeInterval() const 
        return timeInterval;
        
        //#]
    }
    
    //## operation getTimeoutID() 
    public long getTimeoutID() {
        //#[ operation getTimeoutID() 
        return timeoutID;
        
        //#]
    }
    
    //## operation getTimeoutId() 
    public long getTimeoutId() {
        //#[ operation getTimeoutId() 
        return timeoutID;
        
        //#]
    }
    
    //## operation getTimerManager() 
    public RiJTimeoutManager getTimerManager() {
        //#[ operation getTimerManager() 
        return timeoutManager;
        
        //#]
    }
    
    /**
    Instead of > operator.
    */
    //## operation gt(RiJTimeout) 
    public boolean gt(RiJTimeout tm) {
        //#[ operation gt(RiJTimeout) 
        if (dueTime == tm.dueTime)  
          return (timeoutID > tm.timeoutID);
        return (dueTime > tm.dueTime);
        //#]
    }
    
    /**
    Calculates and sets the "absolute" time
    */
    // Argument long now : 
    /**
    The current absolute time
    */
    //## operation resetDueTime(long) 
    public void resetDueTime(long now) {
        //#[ operation resetDueTime(long) 
        dueTime = now + timeInterval;
        //#]
    }
    
    /**
    A convenience method used to send the event to it's destination.
    */
    //## operation toDestination() 
    public void toDestination() {
        //#[ operation toDestination() 
        super.toDestination();
        if (timeoutManager != null)
          timeoutManager.removeExpiredTimeout(this);
        //#]
    }
    
    public Thread getCreatingThread() {
        return creatingThread;
    }
    
    public String getStateName() {
        return stateName;
    }
    
    public RiJTimeoutManager getTimeoutManager() {
        return timeoutManager;
    }
    
    public void setTimeoutManager(RiJTimeoutManager p_RiJTimeoutManager) {
        timeoutManager = p_RiJTimeoutManager;
    }
    
}

