--
-- Parametric Constraints Evaluator
-- MaximaParser.g
--
-- Maxima Expression Parser
--
-- (C) Copyright IBM Corp. 2009 - 2010. All rights reserved.
--
-- Author sakairi
-- Version 2010/01/29
--

%options package=com.ibm.rhapsody.pce.maxima.parser
%options template=dtParserTemplateF.gi
%options import_terminals=MaximaLexer.gi
%options parent_saved,automatic_ast=toplevel,visitor=default,ast_directory=./ast,ast_type=ASTNode

%Define
    $ast_class /.Object./
%End

%Terminals
    LESS_EQUAL ::= '<='
    GREATER_EQUAL ::= '>='
    INEQUALITY ::= '#'
    LESS ::= '<'
    GREATER ::= '>'
    PLUS ::= '+'
    MINUS ::= '-'
    MULTIPLY ::= '*'
    DIVIDE ::= '/'
    EXPONENTIATION ::= "^"
    LPAREN ::= '('
    RPAREN ::= ')'
    EQUALITY ::= '='
    COMMA ::= ','
    DOT ::= '.'
%End

%Start
    Expression
%End

%Rules
    Expression ::= ConditionalExpression

    ConditionalExpression ::= OrExpression
            | 'if' ConditionalExpression 'then' ConditionalExpression ElseifExpression 'else' ConditionalExpression

    ElseifExpression ::= 
            | ElseifExpression 'elseif' ConditionalExpression 'then' ConditionalExpression 

    OrExpression ::= AndExpression
            | OrExpression 'or' AndExpression

    AndExpression ::= NotExpression
            | AndExpression 'and' NotExpression

    NotExpression ::= RelationalExpression
            | 'not' RelationalExpression

    RelationalExpression ::= AdditiveExpression
    RelationalExpression$LessExpression ::= AdditiveExpression '<' AdditiveExpression
    RelationalExpression$LessEqualExpression ::= AdditiveExpression '<=' AdditiveExpression
    RelationalExpression$GreaterEqualExpression ::= AdditiveExpression '>=' AdditiveExpression
    RelationalExpression$GreaterExpression ::= AdditiveExpression '>' AdditiveExpression
    RelationalExpression$EqualityExpression ::= AdditiveExpression '=' AdditiveExpression
    RelationalExpression$InequalityExpression ::= AdditiveExpression '#' AdditiveExpression

    AdditiveExpression ::= MultiplicativeExpression
    AdditiveExpression$AddExpression ::= AdditiveExpression '+' MultiplicativeExpression
    AdditiveExpression$SubtractExpression ::= AdditiveExpression '-' MultiplicativeExpression

    MultiplicativeExpression ::= ExponentiationExpression
    MultiplicativeExpression$MultiplyExpression ::= MultiplicativeExpression '*' ExponentiationExpression
    MultiplicativeExpression$DivideExpression ::= MultiplicativeExpression '/' ExponentiationExpression

    ExponentiationExpression ::= UnaryExpression
            | UnaryExpression '^' ExponentiationExpression

    UnaryExpression ::= PrimaryExpression
    UnaryExpression$PlusUnaryExpression ::= '+' UnaryExpression
    UnaryExpression$MinusUnaryExpression ::= '-' UnaryExpression

    PrimaryExpression ::= Literal
    PrimaryExpression$ParenthesizedExpression ::= '(' ConditionalExpression ')'
    PrimaryExpression$OneArgumentFunction ::= FunctionName '(' ConditionalExpression ')'
    PrimaryExpression$TwoArgumentsFunction ::= FunctionName '(' ConditionalExpression ',' ConditionalExpression ')'
    PrimaryExpression$ThreeArgumentsFunction ::= FunctionName '(' ConditionalExpression ',' ConditionalExpression ',' ConditionalExpression ')'
    PrimaryExpression$Variable ::= IDENTIFIER

    FunctionName ::= IDENTIFIER

    Literal$IntegerLiteral ::= IntegerLiteral
    Literal$RealLiteral ::= RealLiteral
    Literal$BooleanLiteral ::= BooleanLiteral
    Literal$ELiteral ::= ELiteral
    Literal$ImaginaryUnitLiteral ::= ImaginaryUnitLiteral
    Literal$PiLiteral ::= PiLiteral

    BooleanLiteral$TrueLiteral ::= true
    BooleanLiteral$FalseLiteral ::= false
%End
