--
-- Parametric Constraints Evaluator
-- MsmtParser.g
--
-- MATLAB Symbolic Math Toolbox Expression Parser
--
-- (C) Copyright IBM Corp. 2010. All rights reserved.
--
-- Author sakairi
-- Version 2010/03/18
--

%options package=com.ibm.rhapsody.pce.msmt.parser
%options template=dtParserTemplateF.gi
%options import_terminals=MsmtLexer.gi
%options parent_saved,automatic_ast=toplevel,visitor=default,ast_directory=./ast,ast_type=ASTNode

%Define
    $ast_class /.Object./
%End

%Terminals
    PLUS ::= '+'
    MINUS ::= '-'
    MULTIPLY ::= '*'
    DIVIDE ::= '/'
    EXPONENTIATION ::= "^"
    LPAREN ::= '('
    RPAREN ::= ')'
    COMMA ::= ','
%End

%Start
    Expression
%End

%Rules
    Expression ::= AdditiveExpression

    AdditiveExpression ::= MultiplicativeExpression
    AdditiveExpression$AddExpression ::= AdditiveExpression '+' MultiplicativeExpression
    AdditiveExpression$SubtractExpression ::= AdditiveExpression '-' MultiplicativeExpression

    MultiplicativeExpression ::= ExponentiationExpression
    MultiplicativeExpression$MultiplyExpression ::= MultiplicativeExpression '*' ExponentiationExpression
    MultiplicativeExpression$DivideExpression ::= MultiplicativeExpression '/' ExponentiationExpression

    ExponentiationExpression ::= UnaryExpression
            | ExponentiationExpression '^' UnaryExpression

    UnaryExpression ::= PrimaryExpression
    UnaryExpression$PlusUnaryExpression ::= '+' UnaryExpression
    UnaryExpression$MinusUnaryExpression ::= '-' UnaryExpression

    PrimaryExpression ::= Literal
    PrimaryExpression$ParenthesizedExpression ::= '(' AdditiveExpression ')'
    PrimaryExpression$OneArgumentFunction ::= FunctionName '(' AdditiveExpression ')'
    PrimaryExpression$TwoArgumentsFunction ::= FunctionName '(' AdditiveExpression ',' AdditiveExpression ')'
    PrimaryExpression$Variable ::= IDENTIFIER

    FunctionName ::= IDENTIFIER

    Literal$ImaginaryIntegerLiteral ::= IntegerLiteral i
    Literal$ImaginaryRealLiteral ::= RealLiteral i
    Literal$IntegerLiteral ::= IntegerLiteral
    Literal$RealLiteral ::= RealLiteral
    Literal$ImaginaryUnitLiteral ::= i
    Literal$PiLiteral ::= pi
%End
