--
-- Parametric Constraints Evaluator
-- PcelLexer.gi
--
-- Parametric Constraints Expression Language (PCEL) Lexer
--
-- (C) Copyright IBM Corp. 2009. All rights reserved.
--
-- Author sakairi
-- Version 2010/02/03
--

%options package=com.ibm.rhapsody.pce.pcel
%options template=LexerTemplateF.gi
%options filter=PCELKWLexer.gi

%Define
    $kw_lexer_class /.$PCELKWLexer./
%End

%Include
    LexerBasicMapF.gi
%End

%Export
    IDENTIFIER
    IntegerLiteral
    RealLiteral
    LESS_EQUAL
    GREATER_EQUAL
    INEQUALITY
    LESS
    GREATER
    PLUS
    MINUS
    MULTIPLY
    DIVIDE
    EXPONENTIATION
    LPAREN
    RPAREN
    EQUALITY
    COMMA
    DOT
    EQUATION
%End

%Terminals
    CtlCharNotWS

    LF   CR   HT   FF

    a    b    c    d    e    f    g    h    i    j    k    l    m
    n    o    p    q    r    s    t    u    v    w    x    y    z
    _

    A    B    C    D    E    F    G    H    I    J    K    L    M
    N    O    P    Q    R    S    T    U    V    W    X    Y    Z

    0    1    2    3    4    5    6    7    8    9

    AfterASCII   ::= '\u0080..\ufffe'
    Space        ::= ' '
    LF           ::= NewLine
    CR           ::= Return
    HT           ::= HorizontalTab
    FF           ::= FormFeed
    DoubleQuote  ::= '"'
    SingleQuote  ::= "'"
    Percent      ::= '%'
    VerticalBar  ::= '|'
    Exclamation  ::= '!'
    AtSign       ::= '@'
    BackQuote    ::= '`'
    Tilde        ::= '~'
    Sharp        ::= '#'
    DollarSign   ::= '$'
    Ampersand    ::= '&'
    Caret        ::= '^'
    Colon        ::= ':'
    SemiColon    ::= ';'
    BackSlash    ::= '\'
    LeftBrace    ::= '{'
    RightBrace   ::= '}'
    LeftBracket  ::= '['
    RightBracket ::= ']'
    QuestionMark ::= '?'
    Comma        ::= ','
    Dot          ::= '.'
    LessThan     ::= '<'
    GreaterThan  ::= '>'
    Plus         ::= '+'
    Minus        ::= '-'
    Slash        ::= '/'
    Star         ::= '*'
    LeftParen    ::= '('
    RightParen   ::= ')'
    Equal        ::= '='
%End

%Start
    Token
%End

%Rules
    Token ::= identifier     /.    checkForKeyWord();./
            | IntegerLiteral /.    makeToken($_IntegerLiteral);./
            | RealLiteral    /.    makeToken($_RealLiteral);./
            | white          /.    skipToken();./
            | slc            /.    skipToken();./
            | '<' '='        /.    makeToken($_LESS_EQUAL);./
            | '>' '='        /.    makeToken($_GREATER_EQUAL);./
            | '<' '>'        /.    makeToken($_INEQUALITY);./
            | '<'            /.    makeToken($_LESS);./
            | '>'            /.    makeToken($_GREATER);./
            | '+'            /.    makeToken($_PLUS);./
            | '-'            /.    makeToken($_MINUS);./
            | '*'            /.    makeToken($_MULTIPLY);./
            | '/'            /.    makeToken($_DIVIDE);./
            | '^'            /.    makeToken($_EXPONENTIATION);./
            | '('            /.    makeToken($_LPAREN);./
            | ')'            /.    makeToken($_RPAREN);./
            | '=' '='        /.    makeToken($_EQUALITY);./
            | ','            /.    makeToken($_COMMA);./
            | '.'            /.    makeToken($_DOT);./
            | '='            /.    makeToken($_EQUATION);./

    identifier -> nondigit
                | identifier nondigit
                | identifier digit

    IntegerLiteral ::= Integer

    Integer ::= digit
             | Integer digit

    RealLiteral ::= Decimal
                    | Decimal Exponent
                    | Integer Exponent
                    
    Exponent ::= LetterEe Integer
               | LetterEe '-' Integer
               | LetterEe '+' Integer

    LetterEe ::= 'e'
               | 'E'

    Decimal ::= '.' Integer
              | Integer '.'
              | Integer '.' Integer
    
    white ::= whiteChar
            | white whiteChar

    slc ::= '/' '/'
          | slc notEOL

    digit ::= 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9

    aA ::= a | A
    bB ::= b | B
    cC ::= c | C
    dD ::= d | D
    eE ::= e | E
    fF ::= f | F
    gG ::= g | G
    hH ::= h | H
    iI ::= i | I
    jJ ::= j | J
    kK ::= k | K
    lL ::= l | L
    mM ::= m | M
    nN ::= n | N
    oO ::= o | O
    pP ::= p | P
    qQ ::= q | Q
    rR ::= r | R
    sS ::= s | S
    tT ::= t | T
    uU ::= u | U
    vV ::= v | V
    wW ::= w | W
    xX ::= x | X
    yY ::= y | Y
    zZ ::= z | Z

    nondigit ::= '_' | aA | bB | cC | dD | eE | fF | gG | hH | iI | jJ | kK | lL | mM | nN | oO | pP | qQ | rR | sS | tT | uU | vV | wW | xX | yY | zZ

    whiteChar ::= Space | LF | CR | HT | FF

    special ::= '+' | '-' | '(' | ')' | '"' | '!' | '@' | '`' | '~' | '.' |
                '%' | '&' | '^' | ':' | ';' | "'" | '\' | '|' | '{' | '}' |
                '[' | ']' | '?' | ',' | '<' | '>' | '=' | '#' | '*' |
                '/' | '$'

    notEOL ::= nondigit | digit | special | Space | HT | FF
%End
