--
-- Parametric Constraints Evaluator
-- PcelParser.g
--
-- Parametric Constraints Expression Language (PCEL) Parser
--
-- (C) Copyright IBM Corp. 2009 - 2010. All rights reserved.
--
-- Author sakairi
-- Version 2010/01/29
--

%options package=com.ibm.rhapsody.pce.pcel
%options template=dtParserTemplateF.gi
%options import_terminals=PCELLexer.gi
%options parent_saved,automatic_ast=toplevel,visitor=default,ast_directory=./ast,ast_type=ASTNode

%Define
    $ast_class /.Object./
%End

%Terminals
    LESS_EQUAL ::= '<='
    GREATER_EQUAL ::= '>='
    INEQUALITY ::= '<>'
    LESS ::= '<'
    GREATER ::= '>'
    PLUS ::= '+'
    MINUS ::= '-'
    MULTIPLY ::= '*'
    DIVIDE ::= '/'
    EXPONENTIATION ::= "^"
    LPAREN ::= '('
    RPAREN ::= ')'
    EQUALITY ::= '=='
    COMMA ::= ','
    DOT ::= '.'
    EQUATION ::= '='
%End

%Start
    ParametricConstraint
%End

%Rules
    ParametricConstraint ::= Equation 
            | ConditionalExpression

    Equation ::= ConditionalExpression '=' ConditionalExpression

    ConditionalExpression ::= OrExpression
            | 'if' ConditionalExpression 'then' ConditionalExpression ElseifExpression 'else' ConditionalExpression

    ElseifExpression ::= 
            | ElseifExpression 'elseif' ConditionalExpression 'then' ConditionalExpression 

    OrExpression ::= AndExpression
            | OrExpression 'or' AndExpression

    AndExpression ::= NotExpression
            | AndExpression 'and' NotExpression

    NotExpression ::= RelationalExpression
            | 'not' RelationalExpression

    RelationalExpression ::= AdditiveExpression
    RelationalExpression$LessExpression ::= AdditiveExpression '<' AdditiveExpression
    RelationalExpression$LessEqualExpression ::= AdditiveExpression '<=' AdditiveExpression
    RelationalExpression$GreaterEqualExpression ::= AdditiveExpression '>=' AdditiveExpression
    RelationalExpression$GreaterExpression ::= AdditiveExpression '>' AdditiveExpression
    RelationalExpression$EqualityExpression ::= AdditiveExpression '==' AdditiveExpression
    RelationalExpression$InequalityExpression ::= AdditiveExpression '<>' AdditiveExpression

    AdditiveExpression ::= MultiplicativeExpression
    AdditiveExpression$AddExpression ::= AdditiveExpression '+' MultiplicativeExpression
    AdditiveExpression$SubtractExpression ::= AdditiveExpression '-' MultiplicativeExpression
    AdditiveExpression$PlusUnaryExpression ::= '+' MultiplicativeExpression
    AdditiveExpression$MinusUnaryExpression ::= '-' MultiplicativeExpression

    MultiplicativeExpression ::= ExponentiationExpression
    MultiplicativeExpression$MultiplyExpression ::= MultiplicativeExpression '*' ExponentiationExpression
    MultiplicativeExpression$DivideExpression ::= MultiplicativeExpression '/' ExponentiationExpression

    ExponentiationExpression ::= PrimaryExpression
            | PrimaryExpression '^' PrimaryExpression

    PrimaryExpression ::= Literal
    PrimaryExpression$ParenthesizedExpression ::= '(' ConditionalExpression ')'
    PrimaryExpression$OneArgumentFunction ::= FunctionName '(' ConditionalExpression ')'
    PrimaryExpression$TwoArgumentsFunction ::= FunctionName '(' ConditionalExpression ',' ConditionalExpression ')'
    PrimaryExpression$Variable ::= IDENTIFIER

    FunctionName ::= IDENTIFIER

    Literal$IntegerLiteral ::= IntegerLiteral
    Literal$RealLiteral ::= RealLiteral
    Literal$BooleanLiteral ::= BooleanLiteral
    Literal$ELiteral ::= e
    Literal$ImaginaryUnitLiteral ::= i
    Literal$PiLiteral ::= pi

    BooleanLiteral$TrueLiteral ::= true
    BooleanLiteral$FalseLiteral ::= false
%End
