package com.sodius.mdw.core;

import com.sodius.mdw.core.eval.EvaluationManager;
import com.sodius.mdw.core.model.MetamodelManager;

/**
 * The central class of the MDWorkbench platform. 
 * 
 * <p>A workbench can be instantiated using its <code>MDWorkbenchFactory</code>.
 * Evaluations can be launched using the evaluation manager.
 * Once the workbench activity is completed, call the <code>shutdown</code> method to turn off the workbench
 * and to release the license used.</p>
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see MDWorkbenchFactory#create()
 */
public interface MDWorkbench {
    
    /**
     * Returns the host application the workbench is connected with.
     * 
     * @return the workbench host application. 
     */
    public WorkbenchApplication getApplication();
    
    /**
     * Return the configuration in which the workbench runs. 
     * 
     * @return the workbench configuration.
     */
    public WorkbenchConfiguration getConfiguration();
    
    /**
     * Returns the metamodel manager, which provides access to the metamodels available in the environment.
     * 
     * @return the metamodel manager.
     */
    public MetamodelManager getMetamodelManager();
    
    /**
     * Returns the evaluation manager, which provides entry-point services to launch an evaluation.
     * 
     * @return the evaluation manager.
     */
    public EvaluationManager getEvaluationManager();
    
    /**
     * Shutdowns the workbench. 
     * This will release the license used.
     * Once shutdown, this workbench instance can no longer be used.
     */
    public void shutdown();

}
