package com.sodius.mdw.core;

import com.sodius.mdw.internal.core.MDWorkbenchImpl;

/**
 * Main entry-point to instantiate a <code>MDWorkbench</code>.
 * 
 * <p>
 * This class cannot be instantiated or subclassed by clients.
 * </p>
 */
public final class MDWorkbenchFactory {

    /**
     * Creates a new <code>MDWorkbench</code>.
     * 
     * @return a new workbench.
     * @throws CoreException if the workbench could not be instantiated. Reasons include :
     * <ul>
     * <li>No license could be retrieved.</li>
     * </ul>
     */
    public static MDWorkbench create() throws CoreException {
        return new MDWorkbenchImpl();
    }
    
    /**
     * Creates a new <code>MDWorkbench</code> based on the specified application ID.
     * 
     * @param applicationID the host application MDWorkbench must be connected to.
     * @return a new workbench.
     * @throws CoreException if the workbench could not be instantiated. Reasons include :
     * <ul>
     * <li>The application ID is invalid</li>
     * <li>No license could be retrieved for the specified application.</li>
     * </ul>
     */
    public static MDWorkbench create(String applicationID) throws CoreException {
        return new MDWorkbenchImpl(applicationID);
    }
    
    private MDWorkbenchFactory() {
    }
    
}
