package com.sodius.mdw.core;

import com.sodius.mdw.core.util.CommandLine;
import com.sodius.mdw.core.util.log.Logger;

/**
 * Defines properties to configure the workbench.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.MDWorkbench#getConfiguration()
 */
public interface WorkbenchConfiguration {

    /**
     * Return the configured workbench.
     * 
     * @return the workbench.
     */
    public MDWorkbench getWorkbench();
    
    /**
     * Determines wheter the workbench runs in headless mode (no user interface).
     * 
     * <p>This property can be used for example by template and script designers to check wheter they should
     * request options to the end-user through an dialog box or a configuration file.</p>
     * 
     * @return <code>true</code> if the workbench runs in headless mode (no user interface), <code>false</code> otherwise.
     */
    public boolean isHeadless();
    
    /**
     * Specifies wheter the workbench runs in headless mode (no user interface).
     * 
     * @param headless <code>true</code> if the workbench should runs in headless mode (no user interface), <code>false</code> otherwise.
     */
    public void setHeadless(boolean headless);
    
    /**
     * Returns the logger, used to display errors and warnings, as well as debugging information.
     * 
     * @return the logger.
     */
    public Logger getLogger();
    
    /**
     * Sets the logger to use to display errors and warnings, as well as debugging information.
     * 
     * @param logger the logger.
     */
    public void setLogger(Logger logger);
    
    /**
     * Returns the command line that launched the workbench.
     * 
     * @return the main command line.
     */
    public CommandLine getCommandLine();
    
    /**
     * Sets the command line that launched the workbench.
     * 
     * @param commandLine the command line.
     */
    public void setCommandLine(CommandLine commandLine);
    
}
