package com.sodius.mdw.core.eval;

import com.sodius.mdw.core.CoreException;

/**
 * Can be implemented to define an arbitrary sequence of templates and scripts to be evaluated. 
 * 
 * <p>This interface allows to have a fine control on the evaluation process.
 * You generally should consider to rather use a launch configuration.</p>
 * 
 * <p>
 * Clients may implement this interface.
 * </p>
 * 
 * @see EvaluationManager#evaluate(LaunchConfiguration, ProgressMonitor)
 * @see EvaluationManager#evaluate(Project, Evaluable, ProgressMonitor)
 */
public interface Evaluable {
    
    /**
     * Defines an arbitrary sequence of templates and scripts to be evaluated in the specified context.
     * 
     * @param context the evaluation context.
     * @see EvaluationManager#evaluate(Project, Evaluable, ProgressMonitor)
     */
    public void evaluate(EvaluationContext context) throws CoreException;

}
