package com.sodius.mdw.core.eval;

/**
 * Describes a protected section in a text template output.
 * A protected section delimits a region in a file that can contain end-user manual code and that the generator must never overwrite.
 * The protected region allow end-users to insert manual code in the generated output.
 * 
 * <p>A protected section is delimited by a start and an end tag. 
 * These tags can be any arbitrary (language specific) strings, including multiline strings (with '\n' characters).
 * A start delimiter must be unique in the scope of the generated file.</p>
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.GeneratedCode#getProtectedSections()
 */
public interface ProtectedSection {
    
    /**
     * Return the start delimiter of the protected section.
     * This start delimiter must be unique in the scope of the generated file.
     * 
     * @return the start delimiter.
     */
    public String getStartTag();
    
    /**
     * Return the end delimiter of the protected section.
     * 
     * @return the end delimiter.
     */
    public String getEndTag();

}
