package com.sodius.mdw.core.eval.debug;

/**
 * A node representing a read/written model during the evaluation.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 */
public interface ConnectorNode extends DebugNode {

    /**
     * Returns <code>true</code> if the connector used is a model reader.
     * 
     * @return <code>true</code> if the connector used is a model reader, <code>false</code> otherwise.
     * @see com.sodius.mdw.core.model.io.ConnectorDescriptor#isReader()
     */
    public boolean isRead();
    
    /**
     * Returns <code>true</code> if the connector used is a model writer.
     * 
     * @return <code>true</code> if the connector used is a model writer, <code>false</code> otherwise.
     * @see com.sodius.mdw.core.model.io.ConnectorDescriptor#isWriter()
     */
    public boolean isWrite();
    
    /**
     * Returns the name of the connector used.
     * 
     * @return the connector name.
     * @see com.sodius.mdw.core.model.io.ConnectorDescriptor#getName()
     */
    public String getConnectorName();
    
    /**
     * Returns the uri used to read/write the model.
     * 
     * @return the uri used to read/write the model, <code>null</code> if no uri used.
     * @see com.sodius.mdw.core.model.io.ModelReader#read(String, Model, ConnectorContext)
     * @see com.sodius.mdw.core.model.io.ModelWriter#write(String, Model, ConnectorContext)
     */
    public String getURI();
    
    /**
     * Returns a description of the read/written model.
     * 
     * @return a description of the read/written model.
     */
    public ModelValue getModel();
}
