package com.sodius.mdw.core.eval.debug;

import java.io.File;
import java.util.List;

import com.sodius.mdw.core.CoreException;

/**
 * A debug hierarchy is a tree of nodes, each node representing an evaluated element (template, rule or script).
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.EvaluationManager#loadDebugHierarchy(File)
 * @see com.sodius.mdw.core.eval.EvaluationResult#getDebugHierarchy()
 */
public interface DebugHierarchy {
    
    /**
     * Returns the debug hierarchy name, which is the name of the launch configuration.
     * 
     * @return the debug hierarchy name
     */
    public String getName();
    
    /**
     * Returns a description of the evaluated project.
     * 
     * @return a description of the evaluated project.
     */
    public ProjectReference getProject();
    
    /**
     * Returns the top-level evaluated nodes.
     * 
     * @return an unmodifiable list of <code>DebugNode</code> elements.
     * @see DebugNode
     */
    public List<DebugNode> getRootNodes();

    /**
     * Saves this debug hierarchy to the specified file.
     * 
     * @param file the location where to save this hierarchy.
     * @throws CoreException if the hierarchy could not be saved. 
     */
    public void save(File file) throws CoreException;
}
