package com.sodius.mdw.core.eval.debug;

import java.util.List;

/**
 * A node of the debug hierarchy tree. A node describes an evaluated element : template, rule or script.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * @see com.sodius.mdw.core.eval.debug.DebugHierarchy#getRootNodes()
 */
public interface DebugNode {

    /**
     * Returns the containing debug hierarchy.
     * 
     * @return the containing debug hierarchy.
     */
    public DebugHierarchy getHierarchy();
    
    /**
     * Returns <code>true</code> if this is a top-level node (no parent).
     * 
     * @return <code>true</code> if this is a top-level node (no parent), <code>false</code> otherwise.
     */
    public boolean isRoot();
    
    /**
     * Returns the parent node.
     * 
     * @return the parent node, <code>null</code> if this is a root node.
     */
    public DebugNode getParent();
    
    /**
     * Returns <code>true</code> if this node has no child.
     * 
     * @return <code>true</code> if this node has no child, <code>false</code> otherwise.
     */
    public boolean isLeaf();
    
    /**
     * Returns the list of child nodes, ordered the way the corresponding elements were evaluated.
     * 
     * @return an unmodifiable list of <code>DebugNode</code>.
     */
    public List<DebugNode> getChildren();
    
    /**
     * Returns <code>true</code> if the evaluation of the underlying element threw an exception.
     * 
     * @return <code>true</code> if the evaluation of the underlying element threw an exception, <code>false</code> otherwise.
     * @see #getFailure()
     */
    public boolean isFailed();
    
    /**
     * Returns a description of the evaluation exception.
     * 
     * @return a description of the evaluation exception, <code>null</code> if no exception thrown.
     */
    public DebugValue getFailure();
}
