package com.sodius.mdw.core.eval.debug;

import java.util.Collection;

/**
 * Represents a project.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.debug.DebugHierarchy#getProject()
 */
public interface ProjectReference extends ElementReference {

    /**
     * Returns the text templates defined in this project and used during the evaluation.
     * 
     * @return a unmodifiable collection of <code>TextTemplateReference</code> elements.
     * @see TextTemplateReference
     */
    public Collection<TextTemplateReference> getTextTemplates();
    
    /**
     * Returns the rule sets defined in this project and used during the evaluation.
     * 
     * @return a unmodifiable collection of <code>RuleSetReference</code> elements.
     * @see RuleSetReference
     */
    public Collection<RuleSetReference> getRuleSets();
    
    /**
     * Returns the types on which scripts are defined in this project and used during the evaluation.
     * 
     * @return a unmodifiable collection of <code>TypeReference</code> elements.
     * @see TypeReference
     */
    public Collection<TypeReference> getTypes();
}
