package com.sodius.mdw.core.eval.debug;

import com.sodius.mdw.core.eval.project.VisibilityKind;

/**
 * A reference to a project unit (text template or rule set).
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 */
public interface ProjectUnitReference extends ElementReference {

    /**
     * Returns the number of parameters declared by the element.
     * 
     * @return the number of parameters declared by the element. 
     */
    public int getParameterCount();
    
    /**
     * Returns the package name in which this unit is defined (<code>"com.sodius.myPackage"</code> for example).
     * 
     * @return the package name.
     */
    public String getPackageName();
    
    /**
     * Returns the fully qualified name of this unit (<code>"com.sodius.myPackage.MyTemplate"</code> for example).
     * 
     * @return the fully qualified name of this unit.
     */
    public String getQualifiedName();
    
    /**
     * Returns the unit visibility.
     * 
     * @return the unit visibility.
     */
    public VisibilityKind getVisibility();
    
}
