package com.sodius.mdw.core.eval.debug;

import java.util.List;

import com.sodius.mdw.core.eval.project.VisibilityKind;

/**
 * A reference to a rule.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.debug.RuleSetReference#getRules()
 */
public interface RuleReference extends ElementReference {

    /**
     * Returns the number of parameters declared by the element.
     * 
     * @return the number of parameters declared by the element. 
     */
    public int getParameterCount();
    
    /**
     * Returns the container rule set.
     * 
     * @return the container rule set.
     */
    public RuleSetReference getRuleSet();
    
    /**
     * Returns the rule visibility.
     * 
     * @return the rule visibility.
     */
    public VisibilityKind getVisibility();
    
    /**
     * Returns <code>true</code> if this is a subrule.
     * 
     * @return <code>true</code> if this is a subrule, <code>false</code> otherwise.
     */
    public boolean isSubRule();
    
    /**
     * Returns the container rule.
     * 
     * @return the container rule, <code>null</code> if this is not a subrule.
     */
    public RuleReference getParent();
    
    /**
     * Returns the subrules used during the evaluation.
     * 
     * @return a unmodifiable list of <code>RuleReference</code> elements. 
     */
    public List<RuleReference> getSubRules();
}
