package com.sodius.mdw.core.eval.debug;

import java.util.Collection;

/**
 * A reference to a type defining scripts.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.debug.ProjectReference#getTypes()
 */
public interface TypeReference extends ElementReference {

    /**
     * Returns the simple name of this type (<code>"Classifier"</code>, or <code>"Class:EJB"</code> for example).
     * 
     * @return the type simple name.
     * @see #getInstanceClassName()
     */
    public String getName();
    
    /**
     * Returns the Java instance class name that this type represents (<code>"com.sodius.mdw.metamodel.uml21.Classifier"</code> for example).
     * 
     * @return the Java instance class name that this type represents.
     */
    public String getInstanceClassName();
    
    /**
     * Determines wheter this type is defined in a profile.
     * 
     * @return <code>true</code> if this type comes from a profile, <code>false</code> otherwise.
     */
    public boolean isProfileType();
    
    /**
     * Returns the profile name part of this type (<code>"EJB"</code> for example).
     * 
     * @return the profile name part of this type name, <code>null</code> if this is not a profile type.
     * @see #getName()
     * @see #isProfileType()
     */
    public String getProfileName();
    
    /**
     * Returns the scripts defined on this type are which are used during the evaluation.
     * 
     * @return an unmodifiable collection of <code>ScriptReference</code> elements. 
     */
    public Collection<ScriptReference> getScripts();
    
}
