package com.sodius.mdw.core.eval.launch;

import java.io.File;

import com.sodius.mdw.internal.core.eval.launch.LaunchConfigurationImpl;

/**
 * Factory used to create a launch configuration.
 * 
 * <p>
 * This class cannot be instantiated or subclassed by clients.
 * </p>
 */
public final class LaunchConfigurationFactory {
    
    /**
     * Creates a launch configuration to evaluate a text template.
     * 
     * @param projectClasspathFile the file defining the project classpath.
     * @param templateName the fully qualified name of the text template.
     * @return a new launch configuration based on this entry-point.
     */
    public static LaunchConfiguration createTextTemplateConfiguration(File projectClasspathFile, String templateName) {
        return LaunchConfigurationImpl.createTextTemplate(projectClasspathFile, templateName);
    }

    /**
     * Creates a launch configuration to evaluate an entry rule.
     * 
     * @param projectClasspathFile the file defining the project classpath.
     * @param ruleSetName the fully qualified name of the rule set.
     * @param ruleName the name of the entry rule.
     * @return a new launch configuration based on this entry-point.
     */
    public static LaunchConfiguration createRuleConfiguration(File projectClasspathFile, String ruleSetName, String ruleName) {
        return LaunchConfigurationImpl.createRule(projectClasspathFile, ruleSetName, ruleName);
    }

    private LaunchConfigurationFactory() {
    }

}
