package com.sodius.mdw.core.eval.launch;

import java.util.List;

/**
 * References the entry-point element (text template or main rule) to be evaluated.
 * 
 * <p>The referenced project unit (text template or rule set) may define parameters and expects launch arguments.
 * Each unit parameter may have one or two corresponding launch arguments :
 * if a model parameter has an <code>inout</code> direction, 
 * then the launch configuration must define two <code>LaunchModelArgument</code> elements.</p>
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.launch.LaunchConfiguration#getEntryPoint()
 */
public interface LaunchEntryPoint {
    
    /**
     * Returns the fully qualified name of the referenced unit, including its package name.
     * 
     * @return the fully qualified name of the referenced unit.
     */
    public String getQualifiedName();
    
    /**
     * Returns the unit arguments to use.
     * 
     * @return an unmodifiable list of <code>LaunchStringArgument</code> and <code>LaunchModelArgument</code> elements.
     * @see com.sodius.mdw.core.eval.project.ProjectElement#getParameters()
     */
    public List<Object> getArguments();
    
    /**
     * Adds a new <code>String</code> argument, matching a <code>Parameter</code> of the unit.
     * 
     * @param value an argument.
     * @return a <code>LaunchStringArgument</code>, added to the argument list of this entry-point.
     * @see com.sodius.mdw.core.eval.project.Parameter
     */
    public LaunchStringArgument addArgument(String value);
    
    /**
     * Adds a new model argument, matching a <code>ModelParameter</code> of the unit.
     * 
     * @param connectorName the model reader/writer to use.
     * @param uri an uri used to locate the resource to load/save.
     * @return a <code>LaunchModelArgument</code>, added to the argument list of this entry-point.
     * @see com.sodius.mdw.core.eval.project.ModelParameter
     */
    public LaunchModelArgument addArgument(String connectorName, String uri);
}
