package com.sodius.mdw.core.eval.launch;

/**
 * A launch argument matching a <code>ModelParameter</code> of a text template or a rule set.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.launch.LaunchEntryPoint#getArguments()
 */
public interface LaunchModelArgument {

    /**
     * Returns the name of the model connector used to read/write a model.
     * 
     * @return the connector name.
     * @see com.sodius.mdw.core.model.io.ConnectorDescriptor#getName()
     */
    public String getConnectorName();
    
    /**
     * Sets the name of the model connector used to read/write a model.
     * 
     * @param name the connector name.
     * @see com.sodius.mdw.core.model.io.ConnectorDescriptor#getName()
     */
    public void setConnectorName(String name);

    /**
     * Returns the uri used to locate a model resource to read/write.
     * 
     * @return the uri used to locate a model resource to read/write, <code>null</code> if no uri used.
     * @see com.sodius.mdw.core.model.io.ModelReader#read(String, Model, ConnectorContext)
     * @see com.sodius.mdw.core.model.io.ModelWriter#write(String, Model, ConnectorContext)
     */
    public String getURI();
    
    /**
     * Sets the uri used to locate a model resource to read/write. 
     * 
     * @param uri the uri used to locate a model resource to read/write, <code>null</code> if no uri to be used.
     * @see com.sodius.mdw.core.model.io.ModelReader#read(String, Model, ConnectorContext)
     * @see com.sodius.mdw.core.model.io.ModelWriter#write(String, Model, ConnectorContext)
     */
    public void setURI(String uri);
}
