package com.sodius.mdw.core.eval.launch;

import java.util.List;

/**
 * An entry-point representing a main rule to evaluate.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.launch.LaunchConfiguration#getEntryPoint()
 */
public interface RuleEntryPoint extends LaunchEntryPoint {

    /**
     * Returns the name of the top-level rule to evaluate.
     * This rule visibility must be <code>public</code> or <code>entry</code>.
     * 
     * @return the main rule name to evaluate.
     */
    public String getRuleName();
    
    /**
     * Returns the rule arguments to use.
     * 
     * @return an unmodifiable list of <code>LaunchStringArgument</code> elements.
     * @see com.sodius.mdw.core.eval.project.ProjectElement#getParameters()
     */
    public List<LaunchStringArgument> getRuleArguments();
    
    /**
     * Adds a new <code>String</code> argument, matching a <code>Parameter</code> of the rule.
     * 
     * @param value an argument.
     * @return a <code>LaunchStringArgument</code>, added to the argument list of the entry-Point.
     * @see com.sodius.mdw.core.eval.project.Parameter
     */
    public LaunchStringArgument addRuleArgument(String value);
}
