package com.sodius.mdw.core.eval.project;

import java.util.List;

/**
 * An named element, part of a project.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 */
public interface ProjectElement {

    /**
     * Returns the element resource location.
     * 
     * @return the element resource location.
     */
    public Location getLocation();
    
    /**
     * Returns the element name.
     * 
     * @return the element name.
     */
    public String getName();
    
    /**
     * Returns the element visibility.
     * 
     * @return the element visibility.
     */
    public VisibilityKind getVisibility();
    
    /**
     * Returns the list of parameters attached to this element.
     * 
     * <p>If this element is a script or a rule, the returned list will contain instances of <code>Parameter</code>.
     * If it is a template, the returned list may contain <code>Parameter</code> and <code>ModelParameter</code> elements.</p>
     * 
     * @return an unmodifiable list of <code>Parameter</code> and <code>ModelParameter</code> elements.
     */
    public List<Parameter> getParameters(); 
    
    /**
     * Returns the number of parameters of this element.
     * 
     * @return the number of parameters of this element.
     */
    public int getParameterCount();
  
}
