package com.sodius.mdw.core.eval.project;

/**
 * A top-level rule.
 * 
 * <p>This rule always represents a top level rule.
 * Subrules are not subject of interest during evaluations 
 * as they're not visible outside of the defining rule set.</p>
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.project.RuleSet#getRules()
 */
public interface Rule extends ProjectElement {

    /**
     * Returns the rule set in which this rule is defined.
     * 
     * @return the container rule set.
     */
    public RuleSet getRuleSet();
    
    /**
     * Returns the rule visibility.
     * 
     * @return the rule visibility.
     */
    public VisibilityKind getVisibility();
    
    /**
     * Returns the rule resolved return type.
     * 
     * @return the resolved return type.
     */
    public Class<?> getReturnType();
}
