package com.sodius.mdw.core.eval.report;

import java.io.File;
import java.util.List;

import com.sodius.mdw.core.eval.ProtectedSection;

/**
 * Provides information on a file generated by a text template.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see Report#getGeneratedFiles()
 */
public interface GeneratedFile {
    
    /**
     * Returns the absolute path of the generated file.
     * 
     * <p>A text template may output a relative path, which is then resolved against a default evaluation directory.
     * The returned file is the absolute location of this resolved path.</p>
     * 
     * @return the absolute file.
     * @see com.sodius.mdw.core.eval.EvaluationConfiguration#getEvaluationDirectory()
     */
    public File getFile();
    
    /**
     * Returns the encoding used to write the generated file.
     * 
     * @return the generated file encoding, <code>null</code> if encoded with platform default. 
     */
    public String getEncoding();
    
    /**
     * Returns the list of protected sections, which delimit regions in a file 
     * that can contain end-user manual code and that the generator must never overwrite. 
     * 
     * @return an unmodifiable list of <code>ProtectedSection</code> elements.
     * @see com.sodius.mdw.core.eval.ProtectedSection
     */
    public List<ProtectedSection> getProtectedSections();
    
    /**
     * Returns the status of the generated file, which describes the state of the file contents.
     * 
     * @return the generated file status.
     */
    public GeneratedFileStatus getStatus();

}
