package com.sodius.mdw.core.eval.report;

/**
 * Describes the state of a generated file.
 * 
 * <p>
 * This class cannot be instantiated or subclassed by clients.
 * </p>
 * 
 * @see GeneratedFile#getStatus()
 */
public final class GeneratedFileStatus {

    /**
     * The generated file is new, it did not exist before the evaluation started.
     */
    public static final GeneratedFileStatus NEW = new GeneratedFileStatus("new"); //$NON-NLS-1$
    
    /**
     * The generated file already exists, but its contents differs from the previous one.
     */
    public static final GeneratedFileStatus CHANGED = new GeneratedFileStatus("changed"); //$NON-NLS-1$
    
    /**
     * The generated file already exists, and its contents is the same as from the previous one.
     * The file is overwritten only if requested to.
     * @see com.sodius.mdw.core.eval.EvaluationConfiguration#isFileOverwriteForced() 
     */
    public static final GeneratedFileStatus UNCHANGED = new GeneratedFileStatus("unchanged"); //$NON-NLS-1$
    
    /**
     * Determines the file status represented as a <code>String</code> value.
     * 
     * @param value a <code>String</code> representing a file status.
     * @return the corresponding file status.
     * @throws IllegalArgumentException if the value is not recognized.
     */
    public static GeneratedFileStatus valueOf(String value) throws IllegalArgumentException {
        if (NEW.toString().equals(value))
            return NEW;
        
        else if (CHANGED.toString().equals(value))
            return CHANGED;
        
        else if (UNCHANGED.toString().equals(value))
            return UNCHANGED;
        
        else
            throw new IllegalArgumentException(value);
    }
    
    private String name;
    
    private GeneratedFileStatus(String name) {
        this.name = name;
    }
    
    /**
     * Returns a <code>String</code> representation of the file status.
     * 
     * @return the file status as a <code>String</code>.
     */
    public String toString() {
        return name;
    }

}
