package com.sodius.mdw.core.eval.report;

import java.io.File;
import java.util.List;

import com.sodius.mdw.core.CoreException;

/**
 * An evaluation report keeps track of generated files and read/written models during an evaluation.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.EvaluationResult#getReport()
 * @see com.sodius.mdw.core.eval.EvaluationManager#loadReport(File)
 */
public interface Report {
    
    /**
     * Returns the time (in milliseconds) the evaluation has started.
     * 
     * @return the evaluation start timestamp.
     * @see System#currentTimeMillis()
     */
    public long getStartTimestamp();
    
    /**
     * Returns the time (in milliseconds) the evaluation has completed.
     * 
     * @return the evaluation end timestamp.
     * @see System#currentTimeMillis()
     */
    public long getEndTimestamp();
    
    /**
     * Returns the list of files generated during the evaluation.
     * This list is ordered the way files were generated.
     * 
     * @return an unmodifiable list of <code>GeneratedFile</code> elements. 
     * @see GeneratedFile
     */
    public List<GeneratedFile> getGeneratedFiles();
    
    /**
     * Returns this list of the models read/written during the evaluation.
     * This list is ordered the way models were read/written.
     * 
     * @return an unmodifiable list of <code>ReportModel</code> elements.
     * @see ReportModel
     */
    public List<ReportModel> getReportModels();
    
    /**
     * Saves this report into the specified file.
     * 
     * @param file the location where to save report information.
     * @see com.sodius.mdw.core.eval.EvaluationManager#loadReport(File)
     * @throws CoreException if the report could not be saved. 
     */
    public void save(File file) throws CoreException;

}
