package com.sodius.mdw.core.eval.scripts;

import java.util.ArrayList;
import java.util.List;

import com.sodius.mdw.core.eval.EvaluationContext;

/**
 * Base class for Java script containers.
 * 
 * <p>This class provides access to the evaluation context through the field <code>context</code>.
 * The evaluation context provides services that helps to build model transformators/generators.</p>
 * 
 * <p>This class also provides <code>asList</code> methods to call from Java code scripts which expects arguments :
 * <br><code>self.toString("myScript", asList(aStringValue));</code> </p>
 * 
 * <p>
 * This class is not intended to be subclasses by clients.
 * </p>
 */
public abstract class ScriptContainer {
    
    /**
     * Return the current evaluation context.
     * The evaluation context provides services that helps to build model transformators/generators.
     */
    public static EvaluationContext context;
    
    /**
     * Creates a new list with the specified argument.
     * This is a facility to call from Java code scripts which expects arguments :
     * <br><code>self.toString("myScript", asList(aStringValue));</code> 
     * 
     * @return a modifiable list containing the specified argument.
     */
    public static List<Object> asList(Object o1) {
        List<Object> list = new ArrayList<Object>(2);
        list.add(o1);
        return list;
    }
    
    /**
     * Creates a new list with the specified arguments.
     * This is a facility to call from Java code scripts which expects arguments :
     * <br><code>self.toString("myScript", asList(aStringValue, aBooleanValue));</code> 
     * 
     * @return a modifiable list containing the specified arguments.
     */
    public static List<Object> asList(Object o1, Object o2) {
        List<Object> list = new ArrayList<Object>(3);
        list.add(o1);
        list.add(o2);
        return list;
    }
    
    /**
     * Creates a new list with the specified arguments.
     * This is a facility to call from Java code scripts which expects arguments :
     * <br><code>self.toString("myScript", asList(aStringValue, aBooleanValue));</code> 
     * 
     * @return a modifiable list containing the specified arguments.
     */
    public static List<Object> asList(Object o1, Object o2, Object o3) {
        List<Object> list = new ArrayList<Object>(4);
        list.add(o1);
        list.add(o2);
        list.add(o3);
        return list;
    }
    
    /**
     * Creates a new list with the specified arguments.
     * This is a facility to call from Java code scripts which expects arguments :
     * <br><code>self.toString("myScript", asList(aStringValue, aBooleanValue));</code> 
     * 
     * @return a modifiable list containing the specified arguments.
     */
    public static List<Object> asList(Object o1, Object o2, Object o3, Object o4) {
        List<Object> list = new ArrayList<Object>(5);
        list.add(o1);
        list.add(o2);
        list.add(o3);
        list.add(o4);
        return list;
    }
    
    /**
     * Creates a new list with the specified arguments.
     * This is a facility to call from Java code scripts which expects arguments :
     * <br><code>self.toString("myScript", asList(aStringValue, aBooleanValue));</code> 
     * 
     * @return a modifiable list containing the specified arguments.
     */
    public static List<Object> asList(Object o1, Object o2, Object o3, Object o4, Object o5) {
        List<Object> list = new ArrayList<Object>(6);
        list.add(o1);
        list.add(o2);
        list.add(o3);
        list.add(o4);
        list.add(o5);
        return list;
    }
    
    /**
     * Creates a new list with the specified arguments.
     * This is a facility to call from Java code scripts which expects arguments :
     * <br><code>self.toString("myScript", asList(aStringValue, aBooleanValue));</code> 
     * 
     * @return a modifiable list containing the specified arguments.
     */
    public static List<Object> asList(Object o1, Object o2, Object o3, Object o4, Object o5, Object o6) {
        List<Object> list = new ArrayList<Object>(7);
        list.add(o1);
        list.add(o2);
        list.add(o3);
        list.add(o4);
        list.add(o5);
        list.add(o6);
        return list;
    }
}
