package com.sodius.mdw.core.model;

import java.io.File;
import java.net.URL;

/**
 * The configuration from which the metamodel originates.
 * This configuration is used to load metamodel related resources.
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 */
public interface MetamodelConfiguration {
    
    /**
     * Loads a metamodel related class, using the class loader used to load the metamodel.
     * 
     * @param name the name of the class.
     * @return the resulting Class object;
     * @throws ClassNotFoundException if the class was not found.
     * @see ClassLoader#loadClass(java.lang.String)
     */
    public Class<?> loadClass(String name) throws ClassNotFoundException;
    
    /**
     * Finds the resource with the given name, using the class loader used to load the metamodel.
     * 
     * @param name the resource name.
     * @return a <code>URL</code> object for reading the resource, 
     * or <code>null</code> if the resource could not be found or the invoker doesn't have adequate privileges to get the resource.
     * @see ClassLoader#getResource(java.lang.String)
     */
    public URL getResource(String name);
    
    /**
     * Returns the location of the resource that declares the metamodel (<code>metamodels.xml</code>) 
     * or the external connector (<code>connectors.xml</code>). 
     * This can either be a jar file or a directory, depending on the underlying framework configuration.
     * 
     * @return the location of the resource that declares the metamodel or the external connector.
     */
    public File getInstallLocation();

}
