package com.sodius.mdw.core.model;

import java.util.Collection;

import org.eclipse.emf.ecore.EPackage;

/**
 * Defines an extension of a base metamodel, to decorate existing types with new features.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @since MDWorkbench 3.0.0
 */
public interface MetamodelExtension extends Comparable<Object> {

    /**
     * Returns the ID which uniquely identifies this metamodel extension.
     * 
     * @return the unique ID of the metamodel extension.
     */
    public String getId();
    
    /**
     * Returns the name of this metamodel extension.
     * 
     * @return the name of the metamodel extension
     */
    public String getName();

    /**
     * Returns the <code>EPackage</code> declaring this metamodel extension.
     * 
     * @return the <code>EPackage</code> declaring this metamodel extension.
     */
    public EPackage getEPackage();
    
    /**
     * Returns the metamodel extended by this extension.
     * 
     * @return the metamodel this extension applies to.
     */
    public Metamodel getBaseMetamodel();
    
    /**
     * Returns the configuration from which this metamodel extension originates.
     * The configuration can be used to retrieve metamodel extension related resources.
     * 
     * @return the metamodel extension configuration.
     */
    public MetamodelConfiguration getConfiguration();
    
    /**
     * Returns the list of extensions required by this extension to be valid.
     * 
     * @return the list of extensions this extension depends on.
     */
    public Collection<MetamodelExtension> getRequiredMetamodelExtensions();
}
