package com.sodius.mdw.core.model;

import java.util.Collection;

import com.sodius.mdw.core.CoreException;
import com.sodius.mdw.core.MDWorkbench;

/**
 * Provides access to the metamodels available in the environment.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see Metamodel#getManager()
 * @see com.sodius.mdw.core.MDWorkbench#getMetamodelManager()
 */
public interface MetamodelManager {

    /**
     * Returns the workbench.
     * 
     * @return the workbench.
     * @since MDWorkbench 3.0.0
     */
    public MDWorkbench getWorkbench();
    
    /**
     * Returns the metamodels available in the environment.
     * 
     * @return an unmodifiable <code>Collection</code> of <code>Metamodel</code> elements.
     * @see Metamodel
     */
    public Collection<Metamodel> getMetamodels();
    
    /**
     * Returns the metamodel which matches the specified ID.
     * 
     * @return the metamodel which matches the specified ID.
     * @throws CoreException if no metamodel matches this ID.
     */
    public Metamodel getMetamodel(String uniqueID) throws CoreException;
}
