package com.sodius.mdw.core.model;

/**
 * Provides profile capability to a metamodel.
 * 
 * <p>This interface is used to determine the stereotypes of a specific model element.
 * These stereotypes are used to map a model element to a metatype defined in a profile.</p>
 * 
 * <p>Each metamodel may provide its own implementation of this interface.</p>
 * 
 * <p>The concept of stereotype name is neutral here: 
 * UML metamodel implementation will consider the stereotype feature,
 * but a metamodel implementation may map this concept to any arbitrary feature,
 * as long as the feature can be represented with a <code>String</code> value.
 * </p>
 * 
 * <p>
 * Clients may implement this interface.
 * </p>
 */
public interface ProfileProvider {

    /**
     * Determines the stereotype names attached to a model element.
     * 
     * <p>The concept of stereotype name is neutral here: 
     * UML metamodel implementation will consider the stereotype feature,
     * but a metamodel implementation may map this concept to any arbitrary feature,
     * as long as the feature can be represented with a <code>String</code> value.
     * </p>
     * 
     * <p>The implementation should be fast and lightweight, 
     * as this method will be called a lot of time 
     * (each time a method or a script is called on a model element). 
     * </p>
     * 
     * <p>If no stereotype is attached to the model element, 
     * then it is recommended to return <code>null</code> instead of an empty array,
     * for performance consideration (avoids to create unused empty arrays).
     * </p>
     * 
     * @param object the model element we want to determine the stereotypes.
     * @return the attached stereotype names, an empty array or <code>null</code> 
     * if no stereotype is attached to the model element.
     */
    public String[] getStereotypeNames(MDWObject object);
}
