package com.sodius.mdw.core.model;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import org.eclipse.emf.common.util.AbstractEnumerator;

/**
 * Enumeration of known rich text formats.
 * 
 * <p>
 * This class cannot be instantiated or subclassed by clients.
 * </p>
 * 
 * @see RichText
 * @since MDWorkbench 3.1.0
 */
public class RichTextType extends AbstractEnumerator {

    public static final int PLAIN_TEXT = 0;
    public static final RichTextType PLAIN_TEXT_LITERAL = new RichTextType(PLAIN_TEXT, "plainText");

    public static final int XHTML = 1;
    public static final RichTextType XHTML_LITERAL = new RichTextType(XHTML, "xhtml");

    public static final int RTF = 2;
    public static final RichTextType RTF_LITERAL = new RichTextType(RTF, "rtf");

    private static final RichTextType[] VALUES_ARRAY = new RichTextType[] { 
        PLAIN_TEXT_LITERAL, 
        XHTML_LITERAL, 
        RTF_LITERAL, 
    };

    public static final List<RichTextType> VALUES = Collections.unmodifiableList(Arrays.asList(VALUES_ARRAY));

    public static RichTextType get(String name) {
        for (int i = 0; i < VALUES_ARRAY.length; ++i) {
            RichTextType result = VALUES_ARRAY[i];
            if (result.toString().equals(name)) {
                return result;
            }
        }
        return null;
    }

    public static RichTextType get(int value) {
        switch (value) {
        case PLAIN_TEXT:
            return PLAIN_TEXT_LITERAL;
        case XHTML:
            return XHTML_LITERAL;
        case RTF:
            return RTF_LITERAL;
        }
        return null;
    }

    private RichTextType(int value, String name) {
        super(value, name);
    }

}
