package com.sodius.mdw.core.model.diagram;

import java.awt.Dimension;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;

import javax.imageio.stream.FileImageInputStream;

import com.sodius.mdw.core.util.io.IOUtils;
import com.sodius.mdw.internal.core.model.diagram.ImageUtils;

/**
 * A file-based diagram image implementation.
 * 
 * <p>Clients may instantiate or subclass this class.</p>
 *
 * @since 2.1.0
 */
public class DiagramFileImage implements DiagramImage {
    
    private File file;
    private int width  = UNKNOWN_SIZE;
    private int height = UNKNOWN_SIZE;
    
    /**
     * Creates a new diagram image based on the specified file.
     * 
     * <p>This constructor will try to determine the width and height of this image. 
     * Supported image formats are: <code>bmp</code>, <code>emf</code>, <code>gif</code>, <code>jpg</code>, <code>png</code>, and <code>wmf</code>.</p>
     * 
     * @param file the image file.
     */
    public DiagramFileImage(File file) {
        this.file = file;
        
        // parse dimension
        String extension = IOUtils.getFileExtension(file);
        try {
            FileImageInputStream is = new FileImageInputStream(file);
            try { 
                Dimension dimension = ImageUtils.parseDimension(is, extension);
                if (dimension != null) {
                    this.width = dimension.width;
                    this.height = dimension.height;
                }
            }
            finally {
                is.close();
            }
        }
        catch (Throwable e) {
            // ignore, the file format may be unknown
        }
    }

    /**
     * Returns the image file.
     * 
     * @return the image file.
     */
    public final File getFile() {
        return file;
    }
    
    public InputStream openStream() throws IOException {
        return new FileInputStream(file);
    }
    
    public int getWidth() {
        return width;
    }
    
    public int getHeight() {
        return height;
    }
    
    /**
     * This implementation does nothing. Suclasses may override.
     */
    public void dispose() {
        // nothing
    }
}
