package com.sodius.mdw.core.model.diagram;

import java.io.IOException;
import java.io.InputStream;

/**
 * Describes the contents of a diagram image.
 * 
 * @see com.sodius.mdw.core.model.diagram.DiagramProvider
 * @since 2.1.0
 */
public interface DiagramImage {
    
    /**
     * The value used to identify an unknown width or height.
     */
    public static final int UNKNOWN_SIZE = -1;

    /**
     * Opens a <code>InputStream</code> to read image bytes.
     * 
     * @return a stream to read image bytes.
     * @throws IOException if the image contents is not accessible.
     */
    public InputStream openStream() throws IOException;
    
    /**
     * Returns the width of the image.
     * 
     * @return the width of the image (<code>UNKNOWN_SIZE</code> if unknown).
     */
    public int getWidth();
    
    /**
     * Returns the height of the image.
     * 
     * @return the height of the image (<code>UNKNOWN_SIZE</code> if unknown).
     */
    public int getHeight();
    
    /**
     * Dispose the image. 
     * Client who requested this image should call this method when the image is not used anymore.
     */
    public void dispose();
}
