package com.sodius.mdw.core.model.diagram;

import java.io.File;
import java.util.HashMap;
import java.util.Map;

/**
 * Defines options that helps a <code>DiagramProvider</code> to retrieve images.
 * 
 * <p>Clients may instantiate or subclass this class.</p>
 *
 * @since 2.1.0
 */
public class DiagramOptions {
    
    private File directory;
    private String[] formats;
    private Map<String, Object> properties;
    
    /**
     * Returns the directory where the image should be exported, or <code>null</code> if not specified.
     * 
     * @return the directory where the image should be exported, or <code>null</code> if not specified.
     */
    public File getDirectory() {
        return directory;
    }
    
    /**
     * Set the directory where the image should be exported.
     * 
     * @param directory the directory where the image should be exported.
     */
    public void setDirectory(File directory) {
        this.directory = directory;
    }
    
    /**
     * Returns a modifiable <code>Map</code> of user-defined properties.
     * These properties can be used to pass information to a diagram provider.
     * 
     * @return a modifiable <code>Map</code> of user-defined properties.
     */
    public Map<String, Object> getProperties() {
        if (properties == null)
            properties = new HashMap<String, Object>();
        return properties;
    }

    /**
     * Returns a list of preferred file formats (ex: <code>png</code>, <code>jpg</code>, etc.).
     * The list is ordered by preference (the first format in the list is the preferred one).
     * A diagram provider may consult these preferred formats to determine the image type to return.
     * 
     * @return a list of of preferred file formats.
     */
    public String[] getFormats() {
        if (formats == null)
            formats = new String[0];
        return formats;
    }
    
    /**
     * Set the preferred file formats (ex: <code>png</code>, <code>jpg</code>, etc.).
     * 
     * @param formats a list of of preferred file formats.
     * @see #getFormats()
     */
    public void setFormats(String[] formats) {
        this.formats = formats;
    }
}
