package com.sodius.mdw.core.model.diagram;

import com.sodius.mdw.core.CoreException;
import com.sodius.mdw.core.model.MDWObject;
import com.sodius.mdw.core.model.io.ConnectorContext;

/**
 * Provides diagram images related to a model element.
 * 
 * <p>A <code>ModelReader</code> can support diagrams by subclassing this interface.
 * The subclass must be referenced in the <code>metamodels.xml</code> or <code>connectors.xml</code> file 
 * using the property <code>PROPERTY_DIAGRAM_PROVIDER</code>.</p>
 *
 * <p>Please note that many model readers won't be able to support diagrams (XMI reader for example).
 * To support diagrams, a model reader should generally have a live connection with a CASE tool,
 * through COM APIs for example, to be able to dynamically retrieve images.</p>
 * 
 * <p>
 * Clients may implement this interface.
 * </p>
 * 
 * @see com.sodius.mdw.core.model.io.ModelReader
 * @see com.sodius.mdw.core.model.io.ConnectorDescriptor#PROPERTY_DIAGRAM_PROVIDER
 * @since 2.1.0
 */
public interface DiagramProvider {
    
    /**
     * Get the diagram image for a specific model element.
     * 
     * <p>Once the returned <code>DiagramImage</code> is not used anymore, 
     * client should invoke <code>DiagramImage.dispose()</code>.</p>
     * 
     * 
     * @param object a model element which is a logical diagram, or which has an attached diagram.
     * @param options some options used to retrieve the diagram image (may be <code>null</code>).
     * @param context the context used by the <code>ModelReader</code> to load the model.
     * @return the diagram image.
     * @throws CoreException if no diagram image could be retrieved.
     */
    public DiagramImage getDiagram(MDWObject object, DiagramOptions options, ConnectorContext context) throws CoreException;
}
