package com.sodius.mdw.core.model.emf;

import java.util.Map;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.xmi.XMLResource;
import org.eclipse.emf.ecore.xmi.impl.XMIResourceFactoryImpl;

import com.sodius.mdw.core.model.io.ConnectorContext;
import com.sodius.mdw.corext.model.io.xmi.XMI1Resource;
import com.sodius.mdw.corext.model.io.xmi.XMI2ResourceImpl;
import com.sodius.mdw.corext.model.io.xmi.XMIHeader;
import com.sodius.mdw.corext.model.io.xmi.XMILogger;
import com.sodius.mdw.corext.model.io.xmi.XMIVersion;

/**
 * Default EMF based implementation to handle XMI uris.
 * This implementation is able to deal with XMI versions from 1.0 to 2.1.
 */
public class EMFXMIModelReader extends EMFModelReader {

    /**
     * This implementation reads the XMI header and creates a resource that can handle the XMI version found.
     */
    protected Resource createResource(URI uri, ConnectorContext context) {
        try {
            // parse header
            XMIHeader header = XMIHeader.read(uri);
            return createXMIResource(uri, context, header);
        }
        catch (RuntimeException e) {
            throw e;
        }
        catch (Throwable e) {
            throw new RuntimeException(e);
        }
    }
    
    /**
     * Creates a resource that can handle the XMI version found
     */
    protected Resource createXMIResource(URI uri, ConnectorContext context, XMIHeader header) {
        
        // XMI 2.x ?
        if (header.getXMIVersion().equals(XMIVersion.XMI_2_0) || header.getXMIVersion().equals(XMIVersion.XMI_2_1)) {
            Resource.Factory.Registry.INSTANCE.getExtensionToFactoryMap().put("xmi", new XMIResourceFactoryImpl()); //$NON-NLS-1$
            XMI2ResourceImpl resource = new XMI2ResourceImpl(uri);
            resource.setConnectorContext(context);
            return resource;
        }
        
        // XMI 1.x
        else {
            return new XMI1Resource(uri, context, new XMILogger(context.getLogger()), header);
        }
    }

    /**
     * Sets default XMI options.
     */
    protected Map<String,Object> createOptions(ConnectorContext context) {
        Map<String,Object> options = super.createOptions(context);
        options.put(XMLResource.OPTION_RECORD_UNKNOWN_FEATURE, Boolean.TRUE);
        options.put(XMLResource.OPTION_PROCESS_DANGLING_HREF,  XMLResource.OPTION_PROCESS_DANGLING_HREF_RECORD);
        options.put(XMLResource.OPTION_DEFER_IDREF_RESOLUTION, Boolean.TRUE);
        options.put(XMLResource.OPTION_LAX_FEATURE_PROCESSING, Boolean.TRUE);
        return options;
    }
    
}
