package com.sodius.mdw.core.model.io;

/**
 * Describes a file extension handled by a connector.
   Typical use of this extension is to provide a comprehensive file selection dialog box to the end-user.
   
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.model.io.ConnectorDescriptor#getFileExtensions()
 */
public interface FileExtensionDescriptor {
    
    /**
     * Returns the file extension ("xml" for example).
     * 
     * @return the file extension.
     */
    public String getExtension();
    
    /**
     * Returns a description of this file extension ("XML File" for example).
     * 
     * @return a description of the file extension.
     */
    public String getDescription();
    
    /**
     * Determines wheter this file extension is the default extension to handle.
     * 
     * <p>Typical use is to select this extension as the default one in a file selection dialog box.</p>
     * 
     * @return <code>true</code> if this is the default extension, <code>false</code> otherwise.
     * @see com.sodius.mdw.core.model.io.ConnectorDescriptor#getDefaultFileExtension()
     */
    public boolean isDefault();

}
