package com.sodius.mdw.core.model.io;

import com.sodius.mdw.core.CoreException;
import com.sodius.mdw.core.model.Model;

/**
 * Base interface to be implemented by a connector that write models. 
 * 
 * <p>The implementation class specified by the connector descriptor must :
 * <ul>
 * <li>be public</li>
 * <li>implement this interface</li>
 * <li>define a public zero-args constructor</li>
 * </ul>
 * </p>
 * 
 * <p>If you intent to write XML documents, the framework provides facilities you should consider.</p>
 * 
 * <p>Clients may implement this interface.</p>
 * 
 * @see com.sodius.mdw.core.util.io.XMLWriter
 */
public interface ModelWriter {

    /**
     * Writes a model to the specified uri (resource locator).
     * 
     * <p>The uri denotes a resource location to handle. 
     * The form of the uri depends on the connector kind. 
     * If this is a file connector, this uri is expected to be a valid file path.
     * If this is a "no uri" connector, this uri is expected to be <code>null</code> or an empty <code>String</code>.</p>
     * 
     * <p>The specified model contains model elements to be persisted. 
     * Model elements can be retrieved from the model using <code>getInstances</code> methods.</p>
     * 
     * <p>The context can be used to access a variery of properties and is to be used to check for cancellation.</p>
     * 
     * @param uri the location of a resource to write (can be <code>null</code>).
     * @param model the model to be persisted.
     * @param context the context in which this writer runs. 
     * @see ConnectorDescriptor#getKind()
     * @throws CoreException if anything prevents the connector to write the model.
     */
    public void write(String uri, Model model, ConnectorContext context) throws CoreException;
}
