package com.sodius.mdw.core.util;

/**
 * <p>Skeletal implementation of the <code>PropertySet</code> interface.</p>
 * 
 * <p>
 * Clients may subclass this class.
 * </p>
 * 
 * @since 3.1.0
 */
public abstract class AbstractPropertySet implements PropertySet {

    public String getProperty(String name, String defaultValue) {
        Object value = getProperty(name); 
        if (value == null)
            return defaultValue;
        else if (value instanceof String)
            return (String) value;
        else
            return defaultValue;
    }

    public int getProperty(String name, int defaultValue) {
        Object value = getProperty(name); 
        if (value == null)
            return defaultValue;
        else if (value instanceof Integer)
            return ((Integer) value).intValue();
        else if (value instanceof String) {
            try {
                return Integer.parseInt((String) value);
            }
            catch (NumberFormatException e) {
                return defaultValue;
            }
        }
        else
            return defaultValue;
    }

    public boolean getProperty(String name, boolean defaultValue) {
        Object value = getProperty(name); 
        if (value == null)
            return defaultValue;
        else if (value instanceof Boolean)
            return ((Boolean) value).booleanValue();
        else if (value instanceof String) {
            try {
                return Boolean.valueOf((String) value);
            }
            catch (NumberFormatException e) {
                return defaultValue;
            }
        }
        else
            return defaultValue;
    }

    public float getProperty(String name, float defaultValue) {
        Object value = getProperty(name); 
        if (value == null)
            return defaultValue;
        else if (value instanceof Float)
            return ((Float) value).floatValue();
        else if (value instanceof String) {
            try {
                return Float.parseFloat((String) value);
            }
            catch (NumberFormatException e) {
                return defaultValue;
            }
        }
        else
            return defaultValue;
    }

    public void setProperty(String name, String value) {
        setProperty(name, (Object) value); 
    }

    public void setProperty(String name, int value) {
        setProperty(name, Integer.valueOf(value)); 
    }

    public void setProperty(String name, boolean value) {
        setProperty(name, Boolean.valueOf(value)); 
    }

    public void setProperty(String name, float value) {
        setProperty(name, Float.valueOf(value)); 
    }

}
