package com.sodius.mdw.core.util;

import java.text.Collator;
import java.util.Comparator;

/**
 * Compares <code>String</code>s based on natural ordering, i.e. alphanumerically rather than alphabetically.
 * 
 * <p>Clients may instantiate or subclass this class.</p>
 * 
 * @since MDWorkbench 3.0.0
 */
public class AlphanumericComparator implements Comparator<Object> {
    
    public int compare(Object o1, Object o2) {
        char[] s1 = ((String) o1).toCharArray();
        char[] s2 = ((String) o2).toCharArray();

        int offset1 = 0;
        int offset2 = 0;

        while (offset1 < s1.length && offset2 < s2.length) {
            int length1 = getRegionLength(s1, offset1);
            int length2 = getRegionLength(s2, offset2);

            int result = 0;
            if (isDigit(s1[offset1]) && isDigit(s2[offset2])) {
                result = compareDigits(
                        new String(s1, offset1, length1), 
                        new String(s2, offset2, length2));
            }
            else {
                result = Collator.getInstance().compare(
                        new String(s1, offset1, length1), 
                        new String(s2, offset2, length2));
            }

            if (result != 0)
                return result;
            
            offset1 += length1;
            offset2 += length2;
        }

        return s1.length - s2.length;
    }

    private final int getRegionLength(char[] array, int offset) {
        boolean isDigit = isDigit(array[offset]);
        int count = 1;
        
        while (offset + count < array.length && (isDigit == isDigit(array[offset + count]))) {
            count++;
        }
        
        return count;
    }
    
    private boolean isDigit(char c) {
        return c == '.' || Character.isDigit(c);
    }
        
    private int compareDigits(String s1, String s2) {
        int result = 0;
        
        String[] split1 = s1.split("\\."); //$NON-NLS-1$
        String[] split2 = s2.split("\\."); //$NON-NLS-1$
        
        for (int i = 0; result == 0 && i < split1.length && i < split2.length; i++) {
            result = compareTrueDigits(split1[i], split2[i]);
        }
        
        if (result == 0) {
            result = split1.length - split2.length;
        }
        
        return result;
    }
    
    private int compareTrueDigits(String s1, String s2) {
        
        int result = s1.length() - s2.length();
        for (int i = 0; result == 0 && i < s1.length(); i++) {
            result = s1.charAt(i) - s2.charAt(i);
        }
        return result;
    }
    
}