package com.sodius.mdw.core.util;

/**
 * Operations on <code>Class</code>.
 * 
 * <p>
 * This class cannot be instantiated or subclassed by clients.
 * </p>
 */
public final class ClassUtils {

    /**
     * Gets the class name minus the package name from a <code>Class</code>.
     * 
     * @param clazz the class to get the package name for.
     * @return the class name without the package name.
     */
    public static String getSimpleName(Class<?> clazz) {
        return getSimpleName(clazz.getName());
    }
    
    /**
     * Gets the class name minus the package name from a <code>String</code>.
     * <p>The string passed in is assumed to be a class name - it is not checked.</p>
     * 
     * @param className the className to get the package name for.
     * @return the class name without the package name.
     */
    public static String getSimpleName(String className) {
        int dotIndex = className.lastIndexOf('.');
        if (dotIndex < 0 || dotIndex == className.length() - 1)
            return className;
        else
            return className.substring(dotIndex + 1);
    }
    
    /**
     * Gets the package name of a <code>Class</code>.
     * 
     * @param clazz the class to get the package name for.
     * @return the package name.
     */
    public static String getPackageName(Class<?> clazz) {
        return getPackageName(clazz.getName());
    }
    
    /**
     * Gets the package name from a <code>String</code>.
     * <p>The string passed in is assumed to be a class name - it is not checked.
     * If the class is unpackaged, return an empty string.</p>
     * 
     * @param className the className to get the package name for.
     * @return the package name or an empty string.
     */
    public static String getPackageName(String className) {
        int dotIndex = className.lastIndexOf('.');
        if (dotIndex < 0 || dotIndex == className.length() - 1)
            return ""; //$NON-NLS-1$
        else
            return className.substring(0, dotIndex);
    }
    
    private ClassUtils() {
    }
}
