package com.sodius.mdw.core.util;

/**
 * Provides access to the contents of a command line.
 */
public class CommandLine {

    private String[] args;
    private String[] applicationArgs;
    
    /**
     * Returns the complete (not filtered) command line args provided to the MDWorkbench runtime layer when it was first run.
     * 
     * @return the complete command line used to start the platform.
     */
    public String[] getArgs() {
        if (this.args != null)
            return this.args;
        else
            return new String[0];
    }
    
    /**
     * Sets the complete command line args used to launch MDWorkbench.
     * 
     * @param args the command line args used to launch MDWorkbench.
     */
    public void setArgs(String[] args) {
        this.args = args;
    }
    
    /**
     * Returns the application-filtered command line args provided to the MDWorkbench runtime layer when it was first run.
     * The returned value does not include arguments consumed by the lower levels of MDWorkbench (the launcher).
     * 
     * @return the application-filtered command line used to start the platform.
     */
    public String[] getApplicationArgs() {
        if (this.applicationArgs != null)
            return this.applicationArgs;
        else
            return new String[0];
    }
    
    /**
     * Sets the application-filtered command line args used to launch MDWorkbench.
     * 
     * @param args the command line args used to launch MDWorkbench.
     */
    public void setApplicationArgs(String[] args) {
        this.applicationArgs = args;
    }
    
}
