package com.sodius.mdw.core.util.io;

import java.io.File;
import java.io.IOException;

/**
 * Used to write a text template output on disk.
 * One can override the default file writing behavior by defining an implementation of this interface
 * and registering it to the evaluation manager. 
 * 
 * <p>
 * Clients may implement this interface.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.EvaluationManager#setContentWriter(ContentWriter)
 */
public interface ContentWriter {

    /**
     * Writes the specified contents to the specified location.
     * 
     * <p>The specified file may or may not exist at the time this method is invoked.
     * The implementation must create the directory as necessary.</p>
     * 
     * @param file the absolute path of the expected output location.
     * @param charsetName the file encoding to be used, <code>null</code> to use the platform default encoding
     * @param contents the contents to write at the specified location.
     * @throws IOException if the contents could not be written out.
     */
    public void write(File file, String charsetName, String contents) throws IOException;
}
