package com.sodius.mdw.core.util.io;

import java.io.IOException;

import org.xml.sax.InputSource;

import com.sodius.mdw.core.eval.GeneratedCode;

/**
 * Provides access to an input source. 
 * This input source is not necessarily expected to refer to actual XML content.
 * This interface is used to get access to a data content that may be specified using either a character or a byte stream.
 * 
 * <p>
 * Clients may implement this interface.
 * </p>
 * 
 * @see GeneratedCode#setContents(InputSourceProvider)
 * @since 3.2.0
 */
public interface InputSourceProvider {

    /**
     * Gives access to the underlying input source.
     * 
     * @throws IOException if the data content is no longer accessible.
     */
    public InputSource getInputSource() throws IOException;
    
    /**
     * Disposes of this input source.
     * 
     * When used in conjunction with a <code>GeneratedCode<code>, 
     * this method is called when the generated content has been written on disk.
     */
    public void dispose();
}
