package com.sodius.mdw.core.util.io;

import java.io.File;
import java.io.IOException;

import org.xml.sax.InputSource;

/**
 * Generally used to write a doc template output, accessed using an input source, on disk.
 * 
 * <p>
 * Clients may implement this interface.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.EvaluationManager#setContentWriter(ContentWriter)
 * @since 3.2.0
 */
public interface InputSourceWriter extends ContentWriter {

    /**
     * Writes the specified input source content to the specified location.
     * 
     * <p>The specified file may or may not exist at the time this method is invoked.
     * The implementation must create the directory as necessary.</p>
     * 
     * @param file the absolute path of the expected output location.
     * @param charsetName the file encoding to be used, <code>null</code> to use the platform default encoding
     * @param source the input source that gives access to the content to write at the specified location.
     * @throws IOException if the contents could not be written out.
     */
    public void write(File file, String charsetName, InputSource source) throws IOException;
}
