package com.sodius.mdw.core.util.io;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.net.URL;

import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * <p>Default base class for XHTML stream handlers.
 * This handler will resolve XHTML entities using a local cached DTD.
 * This enables to parse XHTML streams without requiring an access to the network.</p>
 * 
 * <p>Clients may subclass this class.</p>
 * 
 * @since MDWorkbench 3.1.0
 */
public class XHTMLDefaultHandler extends DefaultHandler {

    /**
     * Resolves an XHTML entity using a local cached DTD. 
     */
    public InputSource resolveEntity(String publicId, String systemId) throws SAXException, IOException {
        
        // an XHTML DTD stored in this package?
        String name = getSimpleName(systemId);
        if (name != null && name.length() != 0) {
                
            URL url = XHTMLDefaultHandler.class.getResource(name);
            if (url != null) {
                try {
                    InputSource source = new InputSource(url.openStream());
                    source.setSystemId(systemId);
                    source.setPublicId(publicId);
                    return source;
                }
                catch (FileNotFoundException e) {
                    // ignore
                }
                catch (IOException e) {
                    throw new SAXException(e);
                }
            }
        }
        
        return super.resolveEntity(publicId, systemId);
    }
    
    private String getSimpleName(String systemId) {
        if (systemId != null && systemId.length() != 0) {
            int index = systemId.lastIndexOf('/');
            if (index > 0 && index < systemId.length() + 1) {
                return systemId.substring(index + 1);
            }
            else
                return systemId;
        }
            
        return null;
    }
}
