package com.sodius.mdw.core.util.log;

import java.io.PrintStream;

/**
 * Logger implementation which outputs log messages to <code>System.out</code> and <code>System.err</code> streams.
 * 
 * <p>Debug and info messages are logged to <code>System.out</code>.
 * Warnings and errors are logged to <code>System.err</code>.</p>
 * 
 * <p>
 * Clients may instantiate or subclass this class.
 * </p>
 */
public class SystemStreamLogger extends AbstractLogger implements Logger {

    /**
     * Logs the specified message and error to <code>System.out</code> or <code>System.err</code>.
     * 
     * <p>Debug and info messages are logged to <code>System.out</code>.
     * Warnings and errors are logged to <code>System.err</code>.</p>
     * 
     * @param level the log level (known to be loggable).
     * @param message the information to log (usually a <code>String</code>), maybe <code>null</code>.
     * @param error an exception to log, maybe <code>null</code>.
     */
    protected void log(Level level, Object message, Throwable error) {
        
        // determine stream to use
        PrintStream stream = SystemStream.SYSTEM_OUT;
        if (level == Level.WARNING || level == Level.ERROR)
            stream = SystemStream.SYSTEM_ERR;
        
        // message
        if (message != null)
            stream.println(message);
        
        // error stack trace
        if (error != null)
            error.printStackTrace(stream);
    }
}
