package com.sodius.mdw.core.util.progress;

/**
 * An abstract wrapper around a progress monitor which forwards <code>ProgressMonitor</code>
 * methods to the wrapped progress monitor.
 * 
 * <p>
 * Clients may subclass.
 * </p>
 */
public class ProgressMonitorWrapper implements ProgressMonitor {
    
    private ProgressMonitor monitor;

    /** 
     * Creates a new wrapper around the given monitor.
     *
     * @param monitor the progress monitor to forward to.
     */
    public ProgressMonitorWrapper(ProgressMonitor monitor) {
        this.monitor = monitor;
    }
    
    /**
     * Returns the wrapped progress monitor.
     *
     * @return the wrapped progress monitor.
     */
    public ProgressMonitor getWrappedProgressMonitor() {
        return monitor;
    }

    /*
     * Javadoc copied
     */
    public void beginTask(String name, int totalWork) {
        monitor.beginTask(name, totalWork);
    }

    /*
     * Javadoc copied
     */
    public void done() {
        monitor.done();
    }

    /*
     * Javadoc copied
     */
    public void internalWorked(double work) {
        monitor.internalWorked(work);
    }

    /*
     * Javadoc copied
     */
    public boolean isCanceled() {
        return monitor.isCanceled();
    }

    /*
     * Javadoc copied
     */
    public void setCanceled(boolean value) {
        monitor.setCanceled(value);
    }

    /*
     * Javadoc copied
     */
    public void setTaskName(String name) {
        monitor.setTaskName(name);
    }

    /*
     * Javadoc copied
     */
    public void subTask(String name) {
        monitor.subTask(name);
    }

    /*
     * Javadoc copied
     */
    public void worked(int work) {
        monitor.worked(work);
    }
}
