
//Licensed Materials - Property of IBM 
// Copyright IBM Corporation 2006, 2008. All Rights Reserved.

package com.telelogic.rhapsody.core;


/**
 * The IRPApplication interface represents the Rhapsody application, and its methods reflect many of the commands that you can access from the Rhapsody menu bar.
 */
public interface IRPApplication {
	/**
	 * method execute command
	 * @throws RhapsodyRuntimeException
	 */
	public void executeCommand(String commandType, IRPCollection pCommandInitialization, IRPCollection pCommandResult);
	/**
	 * PlugIn window factory
	 * @throws RhapsodyRuntimeException
	 */
	public IRPPlugInWindow getPlugInWindow(int nPlugInID, int nWindowID, int nCreateNew);
	/**
	 * Open ActivexView
	 * @throws RhapsodyRuntimeException
	 */
	public IRPAXViewCtrl openActiveXView(String viewType, IRPCollection pViewInitialization, IRPCollection pExtra);
	/**
	 * method OpenDiagramView
	 * @throws RhapsodyRuntimeException
	 */
	public IRPAXViewCtrl openDiagramView(IRPDiagram diagram);
	/**
	 * checkin license
	 * @throws RhapsodyRuntimeException
	 */
	public void rhpCheckinLicense(String feature);
	/**
	 * checkout license
	 * @throws RhapsodyRuntimeException
	 */
	public String rhpCheckoutLicense(String feature);
	/**
 	 * Returns an IRPProject object representing the project currently open in Rhapsody
 	 * @return IRPProject object that represents the project currently open in Rhapsody
 	 */
	public IRPProject activeProject();
	/**
	 * add To Model
	 * @throws RhapsodyRuntimeException
	 */
	public void addToModel(String filename, int withDescendant);
	/**
	 * add To Model by reference
	 * @throws RhapsodyRuntimeException
	 */
	public void addToModelByReference(String filename);
	/**
	 * add To Model From URL
	 * @throws RhapsodyRuntimeException
	 */
	public void addToModelFromURL(String URL);
	/**
	 * allowBrowserRefresh
	 * @throws RhapsodyRuntimeException
	 */
	public void allowBrowserRefresh(int shouldRefresh);
	/**
	 * allowGERefresh
	 * @throws RhapsodyRuntimeException
	 */
	public void allowGERefresh(int shouldRefresh);
	/**
	 * Called to apply a NewTerms Profile to the active project
	 * @throws RhapsodyRuntimeException
	 */
	public void applyNewTermsProfile(String profileName);
	/**
	 * archive Check Out
	 * @throws RhapsodyRuntimeException
	 */
	public void arcCheckOut(String filename, String label, int isLocked, int isRecursive);
	/**
	 * bring window to top
	 * @throws RhapsodyRuntimeException
	 */
	public void bringWindowToTop();
	/**
 	 * Builds an application using the active component and configuration. Use IRPProject.setActiveComponent and IRPProject.setActiveConfiguration to change the active component and configuration if necessary before calling the build method.
 	 */
	public void build();
	/**
	 * buildEntireProject
	 * @throws RhapsodyRuntimeException
	 */
	public void buildEntireProject();
	/**
	 * buildWithDependencies
	 * @throws RhapsodyRuntimeException
	 */
	public void buildWithDependencies();
	/**
	 * Check if Redo action is available
	 * @throws RhapsodyRuntimeException
	 */
	public int canRedo();
	/**
	 * Check if Undo action is available
	 * @throws RhapsodyRuntimeException
	 */
	public int canUndo();
	/**
	 * check In
	 * @throws RhapsodyRuntimeException
	 */
	public void checkIn(String unitName, String label, int isLocked, int isRecursive, String description);
	/**
	 * check model
	 * @throws RhapsodyRuntimeException
	 */
	public void checkModel();
	/**
	 * check Out
	 * @throws RhapsodyRuntimeException
	 */
	public void checkOut(String unitName, String label, int isLocked, int isRecursive);
	/**
	 * clean
	 * @throws RhapsodyRuntimeException
	 */
	public void clean();
	/**
	 * clear output window
	 * @throws RhapsodyRuntimeException
	 */
	public void clearOutputWindow(String title);
	/**
	 * Close All Animated Sequence diagrams without save
	 * @throws RhapsodyRuntimeException
	 */
	public void closeAllAnimatedSequenceDiagrams(int withSave);
	/**
	 * connect To Archive
	 * @throws RhapsodyRuntimeException
	 */
	public void connectToArchive(String archivePath);
	/**
	 * connectToTarget
	 * @throws RhapsodyRuntimeException
	 */
	public void connectToTarget(String targetName);
	/**
	 * Create a new project and insert it into current workspace
	 * @throws RhapsodyRuntimeException
	 */
	public int createAndInsertProject(String projectLocation, String projectName);
	/**
 	 * creates a new Rhapsody collection object
 	 * @return IRPCollection object that represents the collection that was created. After creating a collection, you can add items to it by calling IRPCollection.addItem or by calling IRPCollection.setSize and then IRPCollection.setModelElement.
 	 */
	public IRPCollection createNewCollection();
	/**
 	 * Creates a new Rhapsody project
 	 * @param projectLocation the directory where the project should be saved, for example, "l:\\temp\\_sample_code"
 	 * @param projectName the name to use for the project. This will be the name used for the .rpy file.
 	 */
	public void createNewProject(String projectLocation, String projectName);
	/**
	 * For debug - check communication in
	 * @throws RhapsodyRuntimeException
	 */
	public void dbgCheckComIn(short i);
	/**
	 * For debug - check communication out
	 * @throws RhapsodyRuntimeException
	 */
	public short dbgCheckComOut();
	/**
	 * Add Rhapsody unit to current project
	 * @throws RhapsodyRuntimeException
	 */
	public void deferredAddToModel(String filename, int withDescendants, String origPrjId, int eraseDir);
	/**
	 * Delete specified project from current workspace
	 * @throws RhapsodyRuntimeException
	 */
	public int deleteProjectFromList(String projectName);
	/**
	 * disconnectFromTarget
	 * @throws RhapsodyRuntimeException
	 */
	public void disconnectFromTarget();
	/**
	 * downloadToTarget
	 * @throws RhapsodyRuntimeException
	 */
	public void downloadToTarget(String filename);
	/**
	 * end undo transaction
	 * @throws RhapsodyRuntimeException
	 */
	public void endUndoTransaction();
	/**
	 * enter Animation Command
	 * @throws RhapsodyRuntimeException
	 */
	public void enterAnimationCommand(String command);
	/**
	 * method errorMessage
	 * @throws RhapsodyRuntimeException
	 */
	public String errorMessage();
	/**
	 * Execute command line
	 * @throws RhapsodyRuntimeException
	 */
	public int executeCommandLine(String commandLine);
	/**
	 * executeTransformationSequence
	 * @throws RhapsodyRuntimeException
	 */
	public void executeTransformationSequence(String transformationSequence, int showTransformedModelPackage);
	/**
	 * expand environment-variable keywords in the provided string
	 * @throws RhapsodyRuntimeException
	 */
	public String expandStringKeywords(String theString);
	/**
	 * Get Rhapsody fixpack
	 * @throws RhapsodyRuntimeException
	 */
	public String fixpack();
	/**
	 * Force output to system console
	 * @throws RhapsodyRuntimeException
	 */
	public void forceOutput2Console(int val);
	/**
	 * forceRoundtrip
	 * @throws RhapsodyRuntimeException
	 */
	public void forceRoundtrip();
	/**
	 * method forceRoundtripElements
	 * @throws RhapsodyRuntimeException
	 */
	public void forceRoundtripElements(IRPCollection elements);
	/**
 	 * Generates code for the entire project, using the active component and configuration. Use IRPProject.setActiveComponent and IRPProject.setActiveConfiguration to change the active component and configuration if necessary before calling the generate method.
 	 */
	public void generate();
	/**
	 * method generateElements
	 * @throws RhapsodyRuntimeException
	 */
	public void generateElements(IRPCollection elements);
	/**
	 * generateEntireProject
	 * @throws RhapsodyRuntimeException
	 */
	public void generateEntireProject();
	/**
	 * Generate Main and Make Files
	 * @throws RhapsodyRuntimeException
	 */
	public void generateMainAndMakeFiles();
	/**
	 * generateWithDependencies
	 * @throws RhapsodyRuntimeException
	 */
	public void generateWithDependencies();
	/**
	 * Get application name
	 * @throws RhapsodyRuntimeException
	 */
	public void getApplicationName(String applicationName, String productRCPName);
	/**
	 * getApplicationStatus
	 * @throws RhapsodyRuntimeException
	 */
	public int getApplicationStatus();
	/**
	 * get property BuildNo
	 * @throws RhapsodyRuntimeException
	 */
	public String getBuildNo();
	/**
	 * get the code generation simplifiers registry
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCodeGenSimplifiersRegistry getCodeGenSimplifiersRegistry();
	/**
	 * for internal use
	 * @throws RhapsodyRuntimeException
	 */
	public IRPDiagSynthAPI getDiagSynthAPI(String clientName);
	/**
	 * get diagram of selected element
	 * @throws RhapsodyRuntimeException
	 */
	public IRPDiagram getDiagramOfSelectedElement();
	/**
	 * Get Error message
	 * @throws RhapsodyRuntimeException
	 */
	public String getErrorMessage();
	/**
	 * getExecutableFolder
	 * @throws RhapsodyRuntimeException
	 */
	public String getExecutableFolder();
	/**
	 * get the External Checker registry
	 * @throws RhapsodyRuntimeException
	 */
	public IRPExternalCheckRegistry getExternalCheckerRegistry();
	/**
	 * get the External IDE registry
	 * @throws RhapsodyRuntimeException
	 */
	public IRPExternalIDERegistry getExternalIDERegistry(String clientID);
	/**
	 * getExternalRoundtripInvoker
	 * @throws RhapsodyRuntimeException
	 */
	public IRPExternalRoundtripInvoker getExternalRoundtripInvoker();
	/**
	 * getIniFileParameterValue
	 * @throws RhapsodyRuntimeException
	 */
	public String getIniFileParameterValue(String sectionName, String paramName);
	/**
	 * get property interfaceName
	 * @throws RhapsodyRuntimeException
	 */
	public String getInterfaceName();
	/**
	 * get property isHiddenUI
	 * @throws RhapsodyRuntimeException
	 */
	public int getIsHiddenUI();
	/**
	 * get property isLoadOnDemand
	 * @throws RhapsodyRuntimeException
	 */
	public int getIsLoadOnDemand();
	/**
	 * get property Language
	 * @throws RhapsodyRuntimeException
	 */
	public String getLanguage();
	/**
	 * get list of factory properties
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getListOfFactoryProperties();
	/**
	 * get list of selected elements
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getListOfSelectedElements();
	/**
	 * get list of site properties
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getListOfSiteProperties();
	/**
 	 * Returns the locale for the version of Rhapsody running.
 	 * @return the locale of the version of Rhapsody running, for example, EN for the English version or JA for the Japanese version
 	 */
	public String getLocaleName();
	/**
	 * Find model element from source code
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement getModelElementFromSource(String sourceData, int isSourceDataIsfileName, int lineNumber);
	/**
	 * get property OMROOT
	 * @throws RhapsodyRuntimeException
	 */
	public String getOMROOT();
	/**
 	 * For internal use only.
 	 */
	public IRPowPaneMgr getOWPaneMgr(String clientID);
	/**
	 * get property projects
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getProjects();
	/**
	 * getRhapsodyHandleErrorFunction
	 * @throws RhapsodyRuntimeException
	 */
	public int getRhapsodyHandleErrorFunction();
	/**
	 * get Rhapsody search manager
	 * @throws RhapsodyRuntimeException
	 */
	public IRPSearchManager getSearchManager();
	/**
	 * get selected element
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement getSelectedElement();
	/**
	 * get selected graph elements
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getSelectedGraphElements();
	/**
	 * Get Selection Interface
	 * @throws RhapsodyRuntimeException
	 */
	public IRPSelection getSelection();
	/**
	 * get property SerialNo
	 * @throws RhapsodyRuntimeException
	 */
	public String getSerialNo();
	/**
	 * get codegeneration interface
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCodeGenerator getTheCodeGeneratorInterface();
	/**
	 * get external code generator invoker
	 * @throws RhapsodyRuntimeException
	 */
	public IRPExternalCodeGeneratorInvoker getTheExternalCodeGeneratorInvoker();
	/**
	 * get integrator interface
	 * @throws RhapsodyRuntimeException
	 */
	public IRPIntegrator getTheIntegratorInterface();
	/**
	 * getTheJavaPluginsInterface
	 * @throws RhapsodyRuntimeException
	 */
	public IRPJavaPlugins getTheJavaPluginsInterface();
	/**
	 * get roundtrip interface
	 * @throws RhapsodyRuntimeException
	 */
	public IRPRoundTrip getTheRoundtripInterface();
	/**
	 * get property ToolSet
	 * @throws RhapsodyRuntimeException
	 */
	public String getToolSet();
	/**
	 * highlight element
	 * @throws RhapsodyRuntimeException
	 */
	public void highLightElement(IRPModelElement val);
	/**
	 * highlight by handle
	 * @throws RhapsodyRuntimeException
	 */
	public void highlightByHandle(String strHandle);
	/**
	 * import Classes
	 * @throws RhapsodyRuntimeException
	 */
	public void importClasses();
	/**
	 * importSyncSimulinkBlock
	 * @throws RhapsodyRuntimeException
	 */
	public void importSyncSimulinkBlock(IRPModelElement simulinkBlock, String simMdlFile, String simSrcFiles, String sampleTime);
	/**
	 * import tlb
	 * @throws RhapsodyRuntimeException
	 */
	public void importTlb(String pPath);
	/**
	 * Insert existing project into current workspace
	 * @throws RhapsodyRuntimeException
	 */
	public IRPProject insertProject(String filename);
	/**
	 * invoke Plugins Method
	 * @throws RhapsodyRuntimeException
	 */
	public void invokePluginsMethod(String methodName);
	/**
	 * Is RhapsodyCL
	 * @throws RhapsodyRuntimeException
	 */
	public int isRhapsodyCL();
	/**
	 * Check if specified extension corresponds to any Rhapsody unit type
	 * @throws RhapsodyRuntimeException
	 */
	public int isRhapsodyFileType(String extension);
	/**
	 * make
	 * @throws RhapsodyRuntimeException
	 */
	public void make();
	/**
	 * mergeElements
	 * @throws RhapsodyRuntimeException
	 */
	public void mergeElements(IRPModelElement left, IRPModelElement right);
	/**
	 * File change notification
	 * @throws RhapsodyRuntimeException
	 */
	public void notifyFileChanged(String filename, int contentChanged);
	/**
	 * Open Advanced Search and Replace dialog
	 * @throws RhapsodyRuntimeException
	 */
	public void openAdvancedSearchAndReplaceDialog();
	/**
	 * method openFileList
	 * @throws RhapsodyRuntimeException
	 */
	public void openFileList(String filename);
	/**
 	 * Opens an existing Rhapsody project
 	 * @param filename the name of the .rpy file, including the full path, for example, "l:\\temp\\_sample_code\\Class_Tricks.rpy"
 	 * @return IRPProject object that represents the Rhapsody project
 	 */
	public IRPProject openProject(String filename);
	/**
	 * open Project From URL
	 * @throws RhapsodyRuntimeException
	 */
	public void openProjectFromURL(String URL);
	/**
	 * open project with last session
	 * @throws RhapsodyRuntimeException
	 */
	public IRPProject openProjectWithLastSession(String filename);
	/**
	 * open project without subunits
	 * @throws RhapsodyRuntimeException
	 */
	public IRPProject openProjectWithoutSubUnits(String filename);
	/**
	 * quit application
	 * @throws RhapsodyRuntimeException
	 */
	public void quit();
	/**
	 * rebuild
	 * @throws RhapsodyRuntimeException
	 */
	public void rebuild();
	/**
	 * rebuildEntireProject
	 * @throws RhapsodyRuntimeException
	 */
	public void rebuildEntireProject();
	/**
	 * rebuildWithDependencies
	 * @throws RhapsodyRuntimeException
	 */
	public void rebuildWithDependencies();
	/**
	 * Perform Redo
	 * @throws RhapsodyRuntimeException
	 */
	public int redo();
	/**
	 * refresh all views
	 * @throws RhapsodyRuntimeException
	 */
	public void refreshAllViews();
	/**
	 * regenerate
	 * @throws RhapsodyRuntimeException
	 */
	public void regenerate();
	/**
	 * method regenerateElements
	 * @throws RhapsodyRuntimeException
	 */
	public void regenerateElements(IRPCollection elements);
	/**
	 * regenerateEntireProject
	 * @throws RhapsodyRuntimeException
	 */
	public void regenerateEntireProject();
	/**
	 * regenerateWithDependencies
	 * @throws RhapsodyRuntimeException
	 */
	public void regenerateWithDependencies();
	/**
	 * register COM client
	 * @throws RhapsodyRuntimeException
	 */
	public void registerCOMClient(int processID, String clientFilename, int magicNumber);
	/**
	 * report
	 * @throws RhapsodyRuntimeException
	 */
	public void report(String format, String outputFileName);
	/**
	 * roundtrip
	 * @throws RhapsodyRuntimeException
	 */
	public void roundtrip();
	/**
	 * method roundtripElements
	 * @throws RhapsodyRuntimeException
	 */
	public void roundtripElements(IRPCollection elements);
	/**
 	 * Runs the application that was built for the project
 	 */
	public void runApplication();
	/**
	 * runHelper
	 * @throws RhapsodyRuntimeException
	 */
	public void runHelper(String helperName);
	/**
	 * runHelperWithParameters
	 * @throws RhapsodyRuntimeException
	 */
	public void runHelperWithParameters(String helperName, String params);
	/**
	 * method saveAll
	 * @throws RhapsodyRuntimeException
	 */
	public void saveAll();
	/**
	 * setApplicationStatus
	 * @throws RhapsodyRuntimeException
	 */
	public void setApplicationStatus(int nStatus);
	/**
	 * set Component
	 * @throws RhapsodyRuntimeException
	 */
	public void setComponent(String component);
	/**
	 * set Configuration
	 * @throws RhapsodyRuntimeException
	 */
	public void setConfiguration(String configuration);
	/**
	 * set property hiddenUI
	 * @throws RhapsodyRuntimeException
	 */
	public void setHiddenUI(boolean pVal);
	/**
	 * set property isLoadOnDemand
	 * @throws RhapsodyRuntimeException
	 */
	public void setIsLoadOnDemand(int isLoadOnDemand);
	/**
	 * set property Language
	 * @throws RhapsodyRuntimeException
	 */
	public void setLanguage(String language);
	/**
	 * set log file
	 * @throws RhapsodyRuntimeException
	 */
	public void setLog(String logFile);
	/**
	 * set property ToolSet
	 * @throws RhapsodyRuntimeException
	 */
	public void setToolSet(String toolSet);
	/**
	 * setUpdateRecentFileList
	 * @throws RhapsodyRuntimeException
	 */
	public void setUpdateRecentFileList(int shouldUpdate);
	/**
	 * start undo transaction
	 * @throws RhapsodyRuntimeException
	 */
	public void startUndoTransaction();
	/**
	 * Terminate the Application
	 * @throws RhapsodyRuntimeException
	 */
	public void terminateApplication();
	/**
	 * Perform Undo
	 * @throws RhapsodyRuntimeException
	 */
	public int undo();
	/**
	 * unloadFromTarget
	 * @throws RhapsodyRuntimeException
	 */
	public void unloadFromTarget();
	/**
	 * unregister COM client
	 * @throws RhapsodyRuntimeException
	 */
	public void unregisterCOMClient(int processID, String clientFilename, int magicNumber);
	/**
	 * Get Rhapsody version
	 * @throws RhapsodyRuntimeException
	 */
	public String version();
	/**
	 * Get Rhapsody versionNumberLong
	 * @throws RhapsodyRuntimeException
	 */
	public String versionNumberLong();
	/**
 	 * Writes text to Rhapsody's Output window.
 	 * @param title the name of the tab to which the text should be written. The possible values are Log, Build, Configuration Management, Animation.
 	 * @param outputStr the text to display in the Output window
 	 */
	public void writeToOutputWindow(String title, String outputStr);
}

