
//Licensed Materials - Property of IBM 
// Copyright IBM Corporation 2006, 2008. All Rights Reserved.

package com.telelogic.rhapsody.core;



public interface IRPGraphElement {
	/**
	 * method addProperty
	 * @throws RhapsodyRuntimeException
	 */
	public void addProperty(String propertyKey, String propertyType, String propertyValue);
	/**
	 * method applyDefaultFormat
	 * @throws RhapsodyRuntimeException
	 */
	public void applyDefaultFormat();
	/**
	 * method getAllGraphicalProperties
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getAllGraphicalProperties();
	/**
	 * method getAllProperties
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getAllProperties();
	/**
	 * get associatedImage
	 * @throws RhapsodyRuntimeException
	 */
	public String getAssociatedImage();
	/**
	 * get property graphicalParent
	 * @throws RhapsodyRuntimeException
	 */
	public IRPGraphElement getGraphicalParent();
	/**
	 * method getGraphicalProperty
	 * @throws RhapsodyRuntimeException
	 */
	public IRPGraphicalProperty getGraphicalProperty(String name);
	/**
	 * get property interfaceName
	 * @throws RhapsodyRuntimeException
	 */
	public String getInterfaceName();
	/**
	 * method getLocalProperties
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getLocalProperties();
	/**
	 * get property modelObject
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement getModelObject();
	/**
	 * method getPropertyValue
	 * @throws RhapsodyRuntimeException
	 */
	public String getPropertyValue(String propertyKey);
	/**
	 * method removeProperty
	 * @throws RhapsodyRuntimeException
	 */
	public void removeProperty(String propertyKey);
	/**
	 * set associatedImage
	 * @throws RhapsodyRuntimeException
	 */
	public void setAssociatedImage(String associatedImage);
	/**
 	 * Sets a new value for a graphical property. Certain graphical properties are available only for specific types of elements. Therefore, before including calls to this method in your code, you should call IRPGraphElement.getAllGraphicalProperties, which returns a collection of IRPGraphicalProperty objects representing the graphical properties available for the element in question. Note that for the name parameter, you only have to provide the property name, not the entire hierarchy as is the case with the method setPropertyValue.
 	 * @param name the name of the graphical property to set
 	 * @param value the value to use for the specified property
 	 */
	public void setGraphicalProperty(String name, String value);
	/**
	 * method setPropertyValue
	 * @throws RhapsodyRuntimeException
	 */
	public void setPropertyValue(String propertyKey, String propertyValue);
}

