
//Licensed Materials - Property of IBM 
// Copyright IBM Corporation 2006, 2008. All Rights Reserved.

package com.telelogic.rhapsody.core;



public interface IRPProject  extends IRPPackage {
	/**
	 * method GatewayExportToXML
	 * @throws RhapsodyRuntimeException
	 */
	public void gatewayExportToXML(String filename, String params);
	/**
	 * method GatewayExportToXML2
	 * @throws RhapsodyRuntimeException
	 */
	public void gatewayExportToXML2(String filename, String params, IRPProject proj);
	/**
	 * method GenerateReport
	 * @throws RhapsodyRuntimeException
	 */
	public void generateReport(String modelscope, String templatename, String docType, String filename, int showDocument, int silentMode);
	/**
	 * method addComponent
	 * @throws RhapsodyRuntimeException
	 */
	public IRPComponent addComponent(String name);
	/**
	 * method addPackage
	 * @throws RhapsodyRuntimeException
	 */
	public IRPPackage addPackage(String name);
	/**
	 * method addProfile
	 * @throws RhapsodyRuntimeException
	 */
	public IRPProfile addProfile(String name);
	/**
	 * method addSpellCheckerResult
	 * @throws RhapsodyRuntimeException
	 */
	public void addSpellCheckerResult(String value);
	/**
	 * method allowAutoSave
	 * @throws RhapsodyRuntimeException
	 */
	public void allowAutoSave(int allow);
	/**
	 * method allowNonUniqueNames
	 * @throws RhapsodyRuntimeException
	 */
	public void allowNonUniqueNames(int allow);
	/**
	 * method applyRoundtripDiffMerge
	 * @throws RhapsodyRuntimeException
	 */
	public void applyRoundtripDiffMerge(int magicNumber, IRPProject shadowModel, IRPCollection filesToUpdate);
	/**
	 * method becomeActiveProject
	 * @throws RhapsodyRuntimeException
	 */
	public void becomeActiveProject();
	/**
	 * method checkEventsBaseIdsSolveCollisions 
	 * @throws RhapsodyRuntimeException
	 */
	public void checkEventsBaseIdsSolveCollisions();
	/**
	 * method cleanUnresolvedElements
	 * @throws RhapsodyRuntimeException
	 */
	public void cleanUnresolvedElements(IRPModelElement rootElement);
	/**
	 * method close
	 * @throws RhapsodyRuntimeException
	 */
	public void close();
	/**
	 * method closeCSVFile
	 * @throws RhapsodyRuntimeException
	 */
	public void closeCSVFile(String fullCSVFileName);
	/**
	 * method deleteComponent
	 * @throws RhapsodyRuntimeException
	 */
	public void deleteComponent(IRPComponent component);
	/**
	 * method endTransactionOfNoCGInterest
	 * @throws RhapsodyRuntimeException
	 */
	public void endTransactionOfNoCGInterest();
	/**
	 * property findComponent
	 * @throws RhapsodyRuntimeException
	 */
	public IRPComponent findComponent(String name);
	/**
	 * method findElementByBinaryID
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement findElementByBinaryID(byte[] theID);
	/**
	 * method findElementByGUID
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement findElementByGUID(String theGUID);
	/**
	 * get property activeComponent
	 * @throws RhapsodyRuntimeException
	 */
	public IRPComponent getActiveComponent();
	/**
	 * get property activeConfiguration
	 * @throws RhapsodyRuntimeException
	 */
	public IRPConfiguration getActiveConfiguration();
	/**
	 * get property allStereotypes
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getAllStereotypes();
	/**
	 * get The code generation simplified-model package
	 * @throws RhapsodyRuntimeException
	 */
	public IRPPackage getCgSimplifiedModelPackage();
	/**
	 * method getCodeGeneratedFiles
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getCodeGeneratedFiles();
	/**
	 * get property components
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getComponents();
	/**
	 * get property defaultDirectoryScheme
	 * @throws RhapsodyRuntimeException
	 */
	public String getDefaultDirectoryScheme();
	/**
	 * method getNewCollaboration
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollaboration getNewCollaboration();
	/**
	 * get property profiles
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getProfiles();
	/**
	 * method getRequirementsByID
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getRequirementsByID(String requirementID, int returnFirstFoundOnly);
	/**
	 * method getRoundtripShadowModel
	 * @throws RhapsodyRuntimeException
	 */
	public IRPProject getRoundtripShadowModel(int magicNumber);
	/**
	 * method highlightFromCode
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement highlightFromCode(String filename, int lineNumber);
	/**
	 * method importPackageFromRose
	 * @throws RhapsodyRuntimeException
	 */
	public void importPackageFromRose(String projectName, String packageName, String logFileName);
	/**
	 * method importProjectFromRose
	 * @throws RhapsodyRuntimeException
	 */
	public void importProjectFromRose(String projectName, String logFileName);
	/**
	 * Check if the project is modified in any part and required to be saved
	 * @throws RhapsodyRuntimeException
	 */
	public int isModifiedRecursive();
	/**
	 * method locateInIDE
	 * @throws RhapsodyRuntimeException
	 */
	public void locateInIDE(IRPConfiguration config, String filename, int lineNumber);
	/**
	 * method openCSVFile
	 * @throws RhapsodyRuntimeException
	 */
	public void openCSVFile(String fullCSVFileName, int reserved);
	/**
	 * method recalculateEventsBaseIds
	 * @throws RhapsodyRuntimeException
	 */
	public void recalculateEventsBaseIds();
	/**
	 * method reloadCSVFile
	 * @throws RhapsodyRuntimeException
	 */
	public void reloadCSVFile(String fullCSVFileName);
	/**
	 * Remove project from current workspace
	 * @throws RhapsodyRuntimeException
	 */
	public int remove();
	/**
	 * method save
	 * @throws RhapsodyRuntimeException
	 */
	public void save();
	/**
	 * method saveAs
	 * @throws RhapsodyRuntimeException
	 */
	public void saveAs(String filename);
	/**
	 * method saveAsPrevVersion
	 * @throws RhapsodyRuntimeException
	 */
	public void saveAsPrevVersion(String filename, String prevVersion);
	/**
 	 * Sets the specified component as the active component for the project.
 	 * @param name the name of the component that should be set as the active component for the project. The string should represent the location of the component in the project hierarchy, using a double colon (::) as the delimiter, for example, Default::subpackage_1::component_a::subcomponent_b. If the component is not contained in a package or within another component, you can just use the name of the component.
 	 */
	public void setActiveComponent(String name);
	/**
 	 * Sets the specified component as the active component for the project.
 	 * @param name the name of the component that should be set as the active component for the project. The string should represent the location of the component in the project hierarchy, using a double colon (::) as the delimiter, for example, Default::subpackage_1::component_a::subcomponent_b. If the component is not contained in a package or within another component, you can just use the name of the component.
 	 */
	public void setActiveComponent(IRPComponent activeComponent);
	/**
	 * method setActiveConfiguration
	 * @throws RhapsodyRuntimeException
	 */
	public void setActiveConfiguration(String name);
	/**
	 * set property activeConfiguration
	 * @throws RhapsodyRuntimeException
	 */
	public void setActiveConfiguration(IRPConfiguration activeConfiguration);
	/**
	 * set property defaultDirectoryScheme
	 * @throws RhapsodyRuntimeException
	 */
	public void setDefaultDirectoryScheme(String defaultDirectoryScheme);
	/**
	 * method setObjectExplicit
	 * @throws RhapsodyRuntimeException
	 */
	public void setObjectExplicit(IRPInstance pInstance);
	/**
	 * method setObjectImplicit
	 * @throws RhapsodyRuntimeException
	 */
	public void setObjectImplicit(IRPInstance pInstance);
	/**
	 * set property UseUniqueStereotypeAndRefCache
	 * @throws RhapsodyRuntimeException
	 */
	public void setUseUniqueStereotypeAndRefCache(int useUniqueStereotypeAndRefCache);
	/**
	 * method setWaitDialogWatchdogValue
	 * @throws RhapsodyRuntimeException
	 */
	public void setWaitDialogWatchdogValue(String value);
	/**
	 * method startTransactionOfNoCGInterest
	 * @throws RhapsodyRuntimeException
	 */
	public void startTransactionOfNoCGInterest();
}

