
//Licensed Materials - Property of IBM 
// Copyright IBM Corporation 2006, 2008. All Rights Reserved.

package com.telelogic.rhapsody.core;



public interface IRPState  extends IRPStateVertex {
	/**
 	 * Adds an ActivityFinal element to an Activity. This method should be called on the root state of the diagram, which you can get by calling IRPStatechart.getRootState().
 	 * @return the ActivityFinal element that was created
 	 */
	public IRPState addActivityFinal();
	/**
	 * method addConnector
	 * @throws RhapsodyRuntimeException
	 */
	public IRPConnector addConnector(String type);
	/**
	 * method addInternalTransition
	 * @throws RhapsodyRuntimeException
	 */
	public IRPTransition addInternalTransition(IRPInterfaceItem trigger);
	/**
 	 * Adds a new substate to this state. If you want to add a new top-level state to your statechart, you can call this method on the root state of the statechart, which you can get by calling IRPStatechart.getRootState(). 
 	 * @param name the name to use for the new state
 	 * @return the state created
 	 */
	public IRPState addState(String name);
	/**
 	 * Adds a termination state to a statechart. This method should be called on the root state of the statechart, which you can get by calling IRPStatechart.getRootState().
 	 * @return the termination state that was created
 	 */
	public IRPState addTerminationState();
	/**
 	 * Creates a default transition within the state.
 	 * @param from the substate that the default transition should lead to
 	 * @return the default transition that was created
 	 */
	public IRPTransition createDefaultTransition(IRPState from);
	/**
 	 * Creates a sub-statechart for the state.
 	 * @return the sub-statechart created
 	 */
	public IRPStatechart createNestedStatechart();
	/**
	 * method deleteConnector
	 * @throws RhapsodyRuntimeException
	 */
	public void deleteConnector(IRPConnector connector);
	/**
	 * method deleteInternalTransition
	 * @throws RhapsodyRuntimeException
	 */
	public void deleteInternalTransition(IRPTransition pVal);
	/**
 	 * Returns the default transition within the state.
 	 * @return the default transition within the state
 	 */
	public IRPTransition getDefaultTransition();
	/**
 	 * Returns the entry action that was defined for the state.
 	 * @return the entry action that was defined for the state
 	 */
	public String getEntryAction();
	/**
 	 * Returns the exit action that was defined for the state.
 	 * @return the exit action that was defined for the state
 	 */
	public String getExitAction();
	/**
 	 * Returns the full name of the state within the statechart, including information about its hierarchical position within the statechart. For example, if your statechart includes a state called Listening within a top-level state called On, the full name would be ROOT.On.Listening.
 	 * @return the full name of the state within the statechart
 	 */
	public String getFullNameInStatechart();
	/**
	 * method getInheritsFrom
	 * @throws RhapsodyRuntimeException
	 */
	public IRPState getInheritsFrom();
	/**
	 * method getInternalTransitions
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getInternalTransitions();
	/**
	 * get isOverridden
	 * @throws RhapsodyRuntimeException
	 */
	public int getIsOverridden();
	/**
	 * get property isReferenceActivity
	 * @throws RhapsodyRuntimeException
	 */
	public int getIsReferenceActivity();
	/**
 	 * Returns the statechart that this state belongs to.
 	 * @return the statechart that this state belongs to
 	 */
	public IRPStatechart getItsStatechart();
	/**
	 * get property itsSwimlane
	 * @throws RhapsodyRuntimeException
	 */
	public IRPSwimlane getItsSwimlane();
	/**
	 * method getLogicalStates
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getLogicalStates();
	/**
 	 * Returns the state's sub-statechart.
 	 * @return the state's sub-statechart
 	 */
	public IRPStatechart getNestedStatechart();
	/**
	 * get property referenceToActivity
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement getReferenceToActivity();
	/**
	 * method getSendAction
	 * @throws RhapsodyRuntimeException
	 */
	public IRPSendAction getSendAction();
	/**
	 * get property stateType
	 * @throws RhapsodyRuntimeException
	 */
	public String getStateType();
	/**
	 * get property subStateVertices
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getSubStateVertices();
	/**
 	 * Returns a collection of the substates contained in this state. Note that this will not work if a state contains a sub-statechart. In such a case, you would have to use code that resembles the following:
 	 * <pre> 
 	 * IRPState parentState = (IRPState)currentProject.findNestedElementRecursive("busy", "State");
 	 * IRPState topLevelStateInSubchart = (IRPState)(parentState.getNestedStatechart().getRootState().getSubStates().getItem(1));
 	 * IRPCollection substates = topLevelStateInSubchart.getSubStates();
 	 * </pre>
 	 * @return the substates contained in this state (collection of IRPState objects)
 	 */
	public IRPCollection getSubStates();
	/**
 	 * Checks whether the state contains one or more And Lines.
 	 * @return 1 if the state contains one or more And Lines, 0 otherwise.
 	 */
	public int isAnd();
	/**
 	 * Checks whether the state is a compound state, meaning a state that contains one or more substates.
 	 * @return 1 if the state is a compound state, 0 otherwise
 	 */
	public int isCompound();
	/**
 	 * Checks whether the state is a leaf state, meaning a state that does not contain any substates.
 	 * @return 1 if the state is a leaf state, 0 if the state contains one or more substates.
 	 */
	public int isLeaf();
	/**
 	 * Checks whether the state is the root state of the statechart.
 	 * @return 1 if the state is the root state of the statechart, 0 otherwise
 	 */
	public int isRoot();
	/**
 	 * Checks whether the state is a Send Action element.
 	 * @return 1 if it is a Send Action element, 0 otherwise
 	 */
	public int isSendActionState();
	/**
	 * method overrideInheritance
	 * @throws RhapsodyRuntimeException
	 */
	public void overrideInheritance();
	/**
	 * method resetEntryActionInheritance
	 * @throws RhapsodyRuntimeException
	 */
	public IRPState resetEntryActionInheritance();
	/**
	 * method resetExitActionInheritance
	 * @throws RhapsodyRuntimeException
	 */
	public IRPState resetExitActionInheritance();
	/**
 	 * Sets the entry action for the state.
 	 * @param entryAction the code to use for the state's entry action
 	 */
	public void setEntryAction(String entryAction);
	/**
 	 * Sets the exit action for the state.
 	 * @param exitAction the code to use for the state's exit action
 	 */
	public void setExitAction(String exitAction);
	/**
	 * method setInternalTransition
	 * @throws RhapsodyRuntimeException
	 */
	public void setInternalTransition(String trigVal, String guardVal, String actionVal);
	/**
	 * set property itsSwimlane
	 * @throws RhapsodyRuntimeException
	 */
	public void setItsSwimlane(IRPSwimlane itsSwimlane);
	/**
	 * set property referenceToActivity
	 * @throws RhapsodyRuntimeException
	 */
	public void setReferenceToActivity(IRPModelElement referenceToActivity);
	/**
	 * set property stateType
	 * @throws RhapsodyRuntimeException
	 */
	public void setStateType(String stateType);
	/**
	 * method unoverrideInheritance
	 * @throws RhapsodyRuntimeException
	 */
	public void unoverrideInheritance();
}

